<?php

/**
 * Briskstar DM_AJAX. AJAX Event Handlers.
 *
 * @class   DM_AJAX
 * @package Briskstar/Classes
 */

defined('ABSPATH') || exit;

/**
 * DM_Ajax class.
 */

use Hybridauth\Exception\Exception;
use Hybridauth\Hybridauth;
use Hybridauth\HttpClient;
use Hybridauth\Storage\Session;

class DM_AJAX
{

	/**
	 * Hook in ajax handlers.
	 */
	public function __construct()
	{
		add_action('init', array($this, 'define_ajax'), 0);
		add_action('template_redirect', array($this, 'do_wc_ajax'), 0);
		self::add_ajax_events();
	}

	/**
	 * Get DM Ajax Endpoint.
	 *
	 * @param string $request Optional.
	 *
	 * @return string
	 */
	public  function get_endpoint($request = '')
	{
		return esc_url_raw(apply_filters('woocommerce_ajax_get_endpoint', add_query_arg('wc-ajax', $request, remove_query_arg(array('remove_item', 'add-to-cart', 'added-to-cart', 'order_again', '_wpnonce'), home_url('/', 'relative'))), $request));
	}

	/**
	 * Set DM AJAX constant and headers.
	 */
	public  function define_ajax()
	{
		// phpcs:disable
		if (! empty($_GET['wc-ajax'])) {
			wc_maybe_define_constant('DOING_AJAX', true);
			wc_maybe_define_constant('DM_DOING_AJAX', true);
			if (! WP_DEBUG || (WP_DEBUG && ! WP_DEBUG_DISPLAY)) {
				@ini_set('display_errors', 0); // Turn off display_errors during AJAX events to prevent malformed JSON.
			}
			$GLOBALS['wpdb']->hide_errors();
		}
		// phpcs:enable
	}

	/**
	 * Send headers for DM Ajax Requests.
	 *
	 * @since 2.5.0
	 */
	private  function wc_ajax_headers()
	{
		if (! headers_sent()) {
			send_origin_headers();
			send_nosniff_header();
			wc_nocache_headers();
			header('Content-Type: text/html; charset=' . get_option('blog_charset'));
			header('X-Robots-Tag: noindex');
			status_header(200);
		} elseif (Constants::is_true('WP_DEBUG')) {
			headers_sent($file, $line);
			trigger_error("wc_ajax_headers cannot set headers - headers already sent by {$file} on line {$line}", E_USER_NOTICE); // @codingStandardsIgnoreLine
		}
	}

	/**
	 * Check for DM Ajax request and fire action.
	 */
	public static function do_wc_ajax()
	{
		global $wp_query;

		// phpcs:disable WordPress.Security.NonceVerification.Recommended
		if (! empty($_GET['wc-ajax'])) {
			$wp_query->set('wc-ajax', sanitize_text_field(wp_unslash($_GET['wc-ajax'])));
		}

		$action = $wp_query->get('wc-ajax');

		if ($action) {
			self::wc_ajax_headers();
			$action = sanitize_text_field($action);
			do_action('wc_ajax_' . $action);
			wp_die();
		}
		// phpcs:enable
	}

	/**
	 * Hook in methods - uses WordPress ajax handlers (admin-ajax).
	 */
	public function add_ajax_events()
	{
		/**
		 * Toggle payment gateway on or off via AJAX.
		 *
		 * @since 3.4.0
		 */
		$ajax_events = array(
			'property_list',
			'property_list_count',
			'sign_up',
			'sing_in',
			'update_profile',
			'loginFrm',
			'otp_verify',
			'otp_resend',
			'forgot_password',
			'Onetime_password',
			'forgot_change_password',
			'popuphtml',
			'document_vault_structure',
			'download_document_valut',
			'donwloaded_document_zip_delete',
			'dd_success',
			'dd_request',
			'datum_logout',
			'changed_password',
			'request_info',
			'read_property_name',
			'resend_email',
			'update_email',
			'send_otp',
			'reset_password',
			'press_release',
			'contact_form',
			'share_property',
			'share_insights',
			'showing_user_detalis',
			'my_property_list',
			'remove_faverites',
			'resend_onetime_password',
			'check_om_access_for_dd',
			'page_view_count',
			'dashboadr_verify_login',
			'is_dashboard_user_check',
			'download_ca_on_mylisting',
			'new_user_register',
			'user_register',
			'omRequest',
			'userAccessRequest',
			'latest_insight',
			'insight_view',
			'insight_doc_tracking',
			'related_insights',
			'insightAccessRequest',
			'NonHostedInsight',
			'checkMobileNumber',
			'get_region_by_state',
			'verifyEmail',
			'resend_email_otp',
			'agreementuser',
			'checkoutUser',
			'membership_confrim_cancel',
			'dashbordLogin',
			'LoginOtp',
			'OMDD',
			'resendmobileotp',
			'resend_email_step'
		);

		foreach ($ajax_events as $ajax_event) {
			add_action('wp_ajax_' . $ajax_event, array($this, $ajax_event));
			add_action('wp_ajax_nopriv_' . $ajax_event, array($this, $ajax_event));
		}
	}

	public function property_list()
	{
		//session_start();
		global $property_post, $datum_user;

		if (isset($_POST['property_filter']) && !empty($_POST['property_filter'])) {
			$_POST['property_filter'] = json_encode($_POST['property_filter']);
		} else {
			$_POST['property_filter'] = '';
		}

		if (isset($_POST['property_status']) && !empty($_POST['property_status'])) {
			$_POST['property_status'] = $_POST['property_status'];
		} else {
			$_POST['property_status'] = '';
		}

		if (isset($_POST['property_type']) && !empty($_POST['property_type'])) {
			$advance_search_type = $_POST['property_type'];
			$_POST['property_type'] = json_encode($_POST['property_type']);
		} else {
			$_POST['property_type'] = '';
		}


		$nextPage = '';
		if (isset($_POST['next_page']) && $_POST['next_page'] != '') {
			$nextPage = '?page=' . $_POST['next_page'];
		}
		$_POST['version'] = '1.1';
		if ($nextPage != '') {
			$data = DM_Curl::HTTPPost($_POST, 'property' . $nextPage);
		} else {
			$data = DM_Curl::HTTPPost($_POST, 'property');
		}

		$property = json_decode($data);
		$nextPageId = '';
		$totalCountProperty = 0;

		if ($property->data->total != null && $property->data->total != '') {
			$totalCountProperty = $property->data->total;
		}

		if ($property->data->next_page_url != null && $property->data->next_page_url != '') {
			$queryParams = parse_url($property->data->next_page_url, PHP_URL_QUERY);
			$queryParams = explode('=', $queryParams);
			$nextPageId = $queryParams[1];
		}
		$result = '';
		$marker = array();
		if (!empty($property->data->data)) {

			if ($property->data->current_page == $property->data->last_page) {
				$view_more = true;
			} else {
				$view_more = false;
			}
			ob_start();
			foreach ($property->data->data as $key => $property_post) {
				global $single_property;
				$single_property = $property_post;
				$arr_askingprice = getDMPropertyAskingPrice();
				/*if ($rowval['is_unpriced'] == 1) {
					$arr_askingprice = 'Unpriced';
				}*/

				include DM_ABSPATH . '/template/content-property.php';
			}

			foreach ($property->map_property as $key => $property_post) {

				global $single_property;
				$single_property = $property_post;
				$arr_askingprice = getDMPropertyAskingPrice();
				$lat = getDMPropertyLatitude();
				$log = getDMPropertyLongitude();

				if ($lat != '' &&  $log != '') {
					$marker[] = array(
						'lat' 	=> getDMPropertyLatitude(),
						'log'   => getDMPropertyLongitude(),
						'title' => getDMPropertyName(),
						'properyurl'	=> getDMProperyURL(),
						'featured_image'	=> getDMPropertyMyListingMarkerListImageLG(),
						'p_status'	 => getDMPropertyListingStatusOnly(),
						'p_price'	 => getDMPropertyAskingPrice(),
						'addr'		 => getDMPropertyCity() . ', ' . getDMPropertyState(),
						'p_type'	 => getDMPropertyPropertyStatus(),
						'p_due_date' => getDMPropertyStatusDateWithDateForMap(getDMPropertyListingStatusOnly())

					);
				}
			}

			$marker_data = json_encode($marker);
			$result = ob_get_clean();
			$response = array(
				'type' 	=> 'success',
				'html'	=> $result,
				'view_more' => $view_more,
				'marker_data'	=> $marker,
				'next_page_id' => $nextPageId,
				'total_property' => $totalCountProperty
			);
		} else {
			ob_start();
			include DM_ABSPATH . '/template/loop/no-products-found.php';
			$response = array(
				'type' 	=> 'success',
				'html'	=> ob_get_clean(),
				'view_more' => true,
				'marker_data'	=> $marker,
			);
		}

		wp_send_json_success($response);
		wp_die();
	}


	public function property_list_count()
	{

		global $property_post, $datum_user;
		$advance_search_type = "";
		if (isset($_POST['property_type']) && !empty($_POST['property_type'])) {
			$advance_search_type = $_POST['property_type'];
			$_POST['property_type'] = json_encode($_POST['property_type']);
		} else {
			$_POST['property_type'] = '';
		}

		if (isset($_POST['property_filter']) && !empty($_POST['property_filter'])) {
			$advance_search_type = $_POST['property_filter'];
			$_POST['property_filter'] = json_encode($_POST['property_filter']);
		} else {
			$_POST['property_filter'] = '';
		}

		if (isset($_POST['property_status']) && !empty($_POST['property_status'])) {
			$_POST['property_status'] = $_POST['property_status'];
		} else {
			$_POST['property_status'] = '';
		}
		$nextPage = '';
		if (isset($_POST['next_page']) && $_POST['next_page'] != '') {
			$nextPage = '?page=' . $_POST['next_page'];
		}
		$_POST['version'] = '1.1';
		if ($nextPage != '') {
			$_POST['user_ip'] = $_SERVER['REMOTE_ADDR'];
			$data = DM_Curl::HTTPPost($_POST, 'property' . $nextPage);
		} else {
			$_POST['user_ip'] = $_SERVER['REMOTE_ADDR'];
			$data = DM_Curl::HTTPPost($_POST, 'property');
		}

		$property = json_decode($data);

		$nextPageId = '';
		$totalCountProperty = 0;

		if ($property->data->total != null && $property->data->total != '') {
			$totalCountProperty = $property->data->total;
		}

		$result = ob_get_clean();
		$response = array(
			'type' 	=> 'success',
			'total_property' => $totalCountProperty
		);

		wp_send_json_success($response);
		wp_die();
	}

	public function sing_in()
	{

		if (!empty($_POST['first_name'])) {
			$_POST['first_name'] = ucwords($_POST['first_name']);
		}

		if (!empty($_POST['last_name'])) {
			$_POST['last_name'] = DM_AJAX::lastNameFields(($_POST['last_name']));
		}

		if (!empty($_POST['suite'])) {
			$_POST['suite'] = DM_AJAX::removeSuiteInSuiteFields(($_POST['suite']));
		}

		if (!empty($_POST['street'])) {
			$_POST['street'] = ucwords(($_POST['street']));
		}

		if (!empty($_POST['city'])) {
			$_POST['city'] = ucwords(($_POST['city']));
		}

		if (!empty($_POST['email'])) {
			$_POST['email'] = strtolower(($_POST['email']));
		}

		if (!empty($_POST['markets'])) {
			$_POST['markets'] = implode(',', $_POST['markets']);
		}
		if (!empty($_POST['cell_phone'])) {
			$_POST['cell_phone'] = str_replace('-', '', $_POST['cell_phone']);
		}
		if (!empty($_POST['mobile_phone'])) {
			$_POST['mobile_phone'] = str_replace('-', '', $_POST['mobile_phone']);
		}

		if (!empty($_POST['PropetyType'])) {
			$_POST['PropetyType'] = json_encode($_POST['PropetyType']);
		}

		if (!empty($_POST['PeferredMarketType'])) {
			$_POST['PeferredMarketType'] = json_encode($_POST['PeferredMarketType']);
		}

		if (!empty($_POST['InvestmentStraragy'])) {
			$_POST['InvestmentStraragy'] = json_encode($_POST['InvestmentStraragy']);
		}

		if (!empty($_POST['ReturnMetrics'])) {
			$_POST['ReturnMetrics'] = json_encode($_POST['ReturnMetrics']);
		}

		if (!empty($_POST['PrefferedDealSize'])) {
			$_POST['PrefferedDealSize'] = json_encode($_POST['PrefferedDealSize']);
		}
		if (!empty($_POST['timing'])) {
			$_POST['timing'] = json_encode($_POST['timing']);
		}

		if (!empty($_POST['Regions'])) {
			$_POST['Regions'] = json_encode($_POST['Regions']);
		}

		if (!empty($_POST['SpacePropetyType'])) {
			$_POST['SpacePropetyType'] = json_encode($_POST['SpacePropetyType']);
		}

		if (!empty($_POST['State'])) {
			$_POST['State'] = json_encode($_POST['State']);
		}

		if (!empty($_POST['State'])) {
			$_POST['State'] = json_encode($_POST['State']);
		}

		if (!empty($_POST['company_radio']) && $_POST['company_radio'] == 1) {
			$_POST['company']	= $_POST['company'];
		} else {
			$_POST['company']	= null;
		}
		if (!empty($_POST['state_select'])) {
			$_POST['state'] = $_POST['state_select'];
		} else if (!empty($_POST['state_text'])) {
			$_POST['state'] = $_POST['state_text'];
		} else {
			$_POST['state'] = '';
		}
		$step = $_POST['step'];


		if (isset($_FILES['avatar'])) {
			$_POST['avatar'] = $_FILES['avatar'];
		}
		$_POST['user_ip'] = $_SERVER['REMOTE_ADDR'];
		$data = DM_Curl::HTTPPost($_POST, 'signup');


		$user = json_decode($data);


		$txt =  $data;
		$myfile = file_put_contents('logs.txt', $txt . PHP_EOL, FILE_APPEND | LOCK_EX);

		if ($user->status == 'success') {
			$response = array(
				'type' 	=> 'success',
				'html'	=> $user->message,
			);
			if ($step == 2) {
				global $datum_user;
				$datum_user = $user->data;
				ob_start();
				include DM_ABSPATH . '/template/auth/user/verify.php';
				$response['html'] = ob_get_clean();
			}
		} else {

			$response = errorcheck($user);
		}
		wp_send_json_success($response);
		wp_die();
	}

	public function update_profile()
	{

		if (!empty($_POST['first_name'])) {
			$_POST['first_name'] = ucwords(strtolower($_POST['first_name']));
		}

		if (!empty($_POST['last_name'])) {
			$_POST['last_name'] = DM_AJAX::lastNameFields(($_POST['last_name']));
		}

		if (!empty($_POST['suite'])) {
			$_POST['suite'] = DM_AJAX::removeSuiteInSuiteFields(($_POST['suite']));
		}

		if (!empty($_POST['street'])) {
			$_POST['street'] = ucwords(strtolower($_POST['street']));
		}

		if (!empty($_POST['city'])) {
			$_POST['city'] = ucwords(strtolower($_POST['city']));
		}

		if (!empty($_POST['email'])) {
			$_POST['email'] = strtolower($_POST['email']);
		}

		if (!empty($_POST['markets'])) {
			$_POST['markets'] = implode(',', $_POST['markets']);
		}
		if (!empty($_POST['cell_phone'])) {
			$_POST['cell_phone'] = str_replace('-', '', $_POST['cell_phone']);
		}
		if (!empty($_POST['mobile_phone'])) {
			$_POST['mobile_phone'] = str_replace('-', '', $_POST['mobile_phone']);
		}

		if (!empty($_POST['state_select'])) {
			if ($_POST['country'] == 'US') {
				$_POST['state'] = $_POST['state_select'];
			} else {
				$_POST['state'] = $_POST['state_text'];
			}
		} else if (!empty($_POST['state_text'])) {
			$_POST['state'] = $_POST['state_text'];
		} else {
			$_POST['state'] = '';
		}
		$step = $_POST['step'];

		if (!empty($_POST['company_radio']) && $_POST['company_radio'] == 1) {
			$_POST['company']	= $_POST['company'];
		} else {
			$_POST['company']	= null;
		}
		if (isset($_FILES['avatar'])) {
			$_POST['avatar'] = $_FILES['avatar'];
		}
		$f = substr($_POST['firstName'], 0, 1);
		$l = substr($_POST['lastName'], 0, 1);

		$_POST['user_ip'] = $_SERVER['REMOTE_ADDR'];
		if (isset($_POST['i_am'])) {
			if ($_POST['i_am'] == 1) {
				unset($_POST['brokertype_h']);
			}
			if ($_POST['i_am'] == 2) {
				unset($_POST['investor_type']);
			}
			if ($_POST['i_am'] == 3) {
				unset($_POST['brokertype_h']);
				unset($_POST['investor_type']);
			}
			if ($_POST['i_am'] == 4) {
				unset($_POST['brokertype_h']);
				unset($_POST['investor_type']);
			}
		}

		if (!empty($_POST['PropetyType'])) {
			$_POST['PropetyType'] = json_encode($_POST['PropetyType']);
		}

		if (!empty($_POST['PeferredMarketType'])) {
			$_POST['PeferredMarketType'] = json_encode($_POST['PeferredMarketType']);
		}

		if (!empty($_POST['InvestmentStraragy'])) {
			$_POST['InvestmentStraragy'] = json_encode($_POST['InvestmentStraragy']);
		}

		if (!empty($_POST['ReturnMetrics'])) {
			$_POST['ReturnMetrics'] = json_encode($_POST['ReturnMetrics']);
		}

		if (!empty($_POST['PrefferedDealSize'])) {
			$_POST['PrefferedDealSize'] = json_encode($_POST['PrefferedDealSize']);
		}

		if (!empty($_POST['timing'])) {
			$_POST['timing'] = json_encode($_POST['timing']);
		}



		if (!empty($_POST['Regions'])) {
			$_POST['Regions'] = json_encode($_POST['Regions']);
		}

		if (!empty($_POST['SpacePropetyType'])) {
			$_POST['SpacePropetyType'] = json_encode($_POST['SpacePropetyType']);
		}

		if (!empty($_POST['State'])) {
			$_POST['State'] = json_encode($_POST['State']);
		}





		if ($_POST['step'] == 2) {
			/* echo "<pre>";
			print_r($_POST);
			die; */
		}

		$data = DM_Curl::HTTPPost($_POST, 'profile');

		// die;
		$user = json_decode($data);

		if ($user->status == 'success') {
			$text = '0';

			if ($user->data->ProfileImage == '') {
				$text = '1';
			}

			$response = array(
				'type' 	=> 'success',
				'html'	=> $user->message,
				'ProfileImage'	=> $user->ProfileImage,
				'text'	=> $text,
				'name'	=> $f . '' . $l,
			);
			if ($step == 2) {
				$response['user_id'] = $user->data->id;
				$response['userAccess'] = $user->userAccess;
				$response['insightsAccess'] = $user->insightsAccess;
			}

			if ($step == 1 && $_POST['i_am'] != 2) {
				global $criteria, $datum_user;

				$data = json_decode(DM_Curl::HTTPGet('check-plugin-key'));
				$datum_user = $data->user_data;


				$data_new 		= DM_Curl::HTTPGet('acquisitioncriteria');
				$criteria 		= json_decode($data_new);

				ob_start();
				include DM_ABSPATH . '/template/auth/user/step/step-2.php';
				$html = ob_get_clean();
				$response['newhtml'] = $html;
			}
		} else {
			$response = array(
				'type' 	=> 'failure',
				'html'	=> $user->errors
			);
		}
		wp_send_json_success($response);
		wp_die();
	}

	public function sign_up()
	{
		$_POST['user_ip'] = $_SERVER['REMOTE_ADDR'];
		$data = DM_Curl::HTTPGet('login', $_POST);
		$user = json_decode($data);
		if ($user->status == 'success') {
			$response = array(
				'type' 	=> 'success',
				'html'	=> $user->message
			);
		} else {
			$response = array(
				'type' 	=> 'failed',
				'html'	=> $user->message
			);
		}
		wp_send_json_success($response);
		wp_die();
	}

	/**
	 * Toggle payment gateway on or off via AJAX.
	 *
	 * @since 3.4.0
	 */
	public function dashboadr_verify_login()
	{
		$v_data = json_decode(base64_decode($_POST['dashboardparameters']));
		if ($v_data->verification_code != $_POST['token'] || empty($v_data)) {
			$response = array(
				'type' 	=> 'failure',
				'html'	=> array('error_login' => 'Some things went wrong')
			);
			wp_send_json_success($response);
			wp_die();
		}
		$_POST['email'] = $v_data->username;
		if ($_POST['email'] != '' && $_POST['password'] != '') {
			$_POST['user_agent'] = $_SERVER['HTTP_USER_AGENT'];
			$_POST['user_ip'] = $_SERVER['REMOTE_ADDR'];
			$data = DM_Curl::HTTPPost($_POST, 'login');
			$user = json_decode($data);
			global $datum_user;
			if (empty($user)) {
				$response = array(
					'type' 	=> 'failure',
					'html'	=> array('error_login' => 'Some things went wrong')
				);
			} else {
				if ($user->status == 'failed') {
					$response = array(
						'type' 	=> 'failure',
						'html'	=> array('error_login' => $user->message)
					);
				} else {
					if ($user->isVerifiedUser == 'yes') {
						$response = array(
							'type' 	=> 'failure',
							'html'	=> array('error_login' => $user->message)
						);
					} else {
						$datum_user = $user->data->user;
						if (!$user->data->user->IsAccountVerified) {
							ob_start();
							include DM_ABSPATH . '/template/auth/verify.php';
							$response = array(
								'type' 	=> 'success',
								'html'	=> ob_get_clean(),
								'IsAccountVerified'	=> 0,
							);
						} else if ($user->isNextUpdateDate) {
							global $criteria;
							$upload 	= wp_upload_dir();
							$cookie_name 	= "access_token";
							$cookie_value 	= $user->access_token;

							$data_new 		= DM_Curl::HTTPGet('acquisitioncriteria');
							$criteria 		= json_decode($data_new);

							setcookie($cookie_name, $cookie_value, time() + 86400, "/");
							ob_start();
							include DM_ABSPATH . '/template/auth/1031updateprofile.php';
							$response = array(
								'type' 				=> 'success',
								'html'				=> ob_get_clean(),
								'isNextUpdateDate'	=> 1,
							);
						} else if ($user->IsContactCreatedByDashboard  != '' && $user->IsupdateDashbord == '') {
							global $criteria;
							$upload 	= wp_upload_dir();
							$cookie_name 	= "access_token";
							$cookie_value 	= $user->access_token;

							$data_new 		= DM_Curl::HTTPGet('acquisitioncriteria');
							$criteria 		= json_decode($data_new);

							setcookie($cookie_name, $cookie_value, time() + 86400, "/");
							ob_start();
							include DM_ABSPATH . '/template/auth/1031updateprofile.php';
							$response = array(
								'type' 				=> 'success',
								'html'				=> ob_get_clean(),
								'isNextUpdateDate'	=> 1,
							);
						}
					}
				}
			}
		}
		wp_send_json_success($response);
		wp_die();
	}

	/**
	 * Toggle payment gateway on or off via AJAX.
	 *
	 * @since 3.4.0
	 */

	public function loginFrm()
	{
		global $social_email, $high_security, $dddocflag;
		$_POST['user_agent'] = $_SERVER['HTTP_USER_AGENT'];
		$_POST['user_ip'] = $_SERVER['REMOTE_ADDR'];

		if (isset($_POST['type']) && $_POST['type'] == 'social') {
			$storage 		= new Session();
			$social_email 	= $storage->get('social_email');
			$_POST['social_login'] = 'social';
			//$_POST['email'] = $social_email;
			$storage->set('provider', null);
			$storage->set('type', null);
			$config = [
				'callback' => home_url(),
				'providers' => [
					'LinkedIn' => [
						'enabled' => true,
						'keys' => [
							'id' => '7848fcb29l5sna',
							'secret' => 'UNUsWqRREMayzqsV',
						],
						"scope"   => "r_liteprofile r_emailaddress",
					],
				]
			];

			$hybridauth     = new Hybridauth($config);
			$adapter        = $hybridauth->authenticate('LinkedIn');

			$adapter = $hybridauth->getAdapter('LinkedIn');
			$adapter->disconnect();
		}

		$data = DM_Curl::HTTPPost($_POST, 'login');

		$user = json_decode($data);

		global $datum_user;
		$favoriteFlag = [];
		$favoriteFlag['favrite'] = '';
		$favoriteFlag['remove_favrite'] = '';
		$favoriteFlag['popup'] = true;

		if (empty($user)) {
			$response = array(
				'type' 	=> 'failure',
				'html'	=> array('error_login' => 'Some things went wrong')
			);
		} else {
			if ($user->status == 'failed') {
				$response = array(
					'type' 	=> 'failure',
					'html'	=> array('error_login' => $user->message)
				);
			} else {
				global $criteria;

				$datum_user = $user->data->user->data;


				if (isset($user->data->user->IsRegistrationCompleted) && $user->data->user->IsRegistrationCompleted == 0) {
					
					if ($user->data->user->IsSocial == 1) {
						global $criteria;
							global $datum_user;
							$data_new 		= DM_Curl::HTTPGet('acquisitioncriteria');
							$criteria 		= json_decode($data_new);
							$datum_user = $user->data->user->data;

							ob_start();
							include DM_ABSPATH . '/template/auth/user/registerlinkedinprofile.php';
						$response = array(
							'type' 				=> 'success',
							'html'				=> ob_get_clean(),
							'IsRegistrationCompleted'	=> $user->data->user->IsRegistrationCompleted,
							'IsAccountVerified'	=>  $user->data->user->IsAccountVerified
						);
					} else {
						global $datum_user;

						if($user->data->user->IsRegistrationCompleted == 0 && empty($user->data->user->data->Username) ){
							global $criteria;
							global $datum_user;
							$data_new 		= DM_Curl::HTTPGet('acquisitioncriteria');
							$criteria 		= json_decode($data_new);
							$datum_user = $user->data->user;
							ob_start();
							include DM_ABSPATH . '/template/auth/user/registerprofile.php';
							$response = array(
								'type' 		=> 'success',
								'html'		=> ob_get_clean(),
								'email'		=> $user->data->user->email,
								'password'	=> $_POST['password'],
								'user_id'	=> $user->data->user->Id,
								'IsRegistrationCompleted'	=> $user->data->user->IsRegistrationCompleted,
								'IsAccountVerified'	=>  $user->data->user->IsAccountVerified
							);
							
						}else{

							$response = array(
								'type' 			=> 'failure',
								'html'			=> array('error_login' => $user->message),
							);
						}
					}

					
				} else if (!$user->data->user->IsAccountVerified) {
					//die('dd2');
					ob_start();
					include DM_ABSPATH . '/template/auth/user/step/verify.php';
					$response = array(
						'type' 	=> 'success',
						'html'	=> ob_get_clean(),
						'IsAccountVerified'	=> 0,
					);
				} else if ($user->isNextUpdateDate) {
					//die('dd3');
					global $criteria;
					if (isset($_POST['property_id']) && $_POST['property_id'] != "") {
						$property_id = $_POST['property_id'];
						$id = "get-property/" . $property_id . "/0";
						$device = 0;
						if (wp_is_mobile()) {
							$device = 1;
						}
						$pageViewData = array('id' => $property_id, 'ip' => $_SERVER['REMOTE_ADDR'], 'device' => $device);
						$data_view  = DM_Curl::HTTPPost($pageViewData, 'page-view', true, $user->access_token, array());
					}
					$upload 	= wp_upload_dir();
					$cookie_name 	= "access_token";
					$cookie_value 	= $user->access_token;

					$data_new 		= DM_Curl::HTTPGet('acquisitioncriteria');
					$criteria 		= json_decode($data_new);

					setcookie($cookie_name, $cookie_value, time() + 86400, "/");
					ob_start();
					include DM_ABSPATH . '/template/auth/1031updateprofile.php';
					$response = array(
						'type' 				=> 'success',
						'html'				=> ob_get_clean(),
						'isNextUpdateDate'	=> 1,
					);
				} else if ($user->IsContactCreatedByDashboard  != '' && $user->IsupdateDashbord == '') {
					//die('dd4');
					global $criteria;
					if (isset($_POST['property_id']) && $_POST['property_id'] != "") {
						$property_id = $_POST['property_id'];
						$id = "get-property/" . $property_id . "/0";
						$device = 0;
						if (wp_is_mobile()) {
							$device = 1;
						}
						$pageViewData = array('id' => $property_id, 'ip' => $_SERVER['REMOTE_ADDR'], 'device' => $device);
						$data_view  = DM_Curl::HTTPPost($pageViewData, 'page-view', true, $user->access_token, array());
					}
					$upload 	= wp_upload_dir();
					$cookie_name 	= "access_token";
					$cookie_value 	= $user->access_token;

					$data_new 		= DM_Curl::HTTPGet('acquisitioncriteria');
					$criteria 		= json_decode($data_new);

					setcookie($cookie_name, $cookie_value, time() + 86400, "/");
					ob_start();
					include DM_ABSPATH . '/template/auth/1031updateprofile.php';
					$response = array(
						'type' 				=> 'success',
						'html'				=> ob_get_clean(),
						'isNextUpdateDate'	=> 1,
					);
				} else {

					$upload 	= wp_upload_dir();
					//if ($user->data->user->data->IndustryRoleId == 1 || $user->data->user->data->IndustryRoleId == 4) {
						$cookie_name 	= "access_token";
						$cookie_value 	= $user->access_token;
						setcookie($cookie_name, $cookie_value, time() + 86400, "/");
					//}


					///$pr_user = $datum_user;

					global $single_property, $datum_user;
					$property_id = $_POST['property_id'];
					$id = "get-property/" . $property_id . "/0";
					$data = DM_Curl::HTTPGet($id, array(), $user->access_token);
					$property = json_decode($data);
					$single_property = $property->data;

					//$response['otp'] 	= 0;
					// if ($user->data->user->data->IndustryRoleId == 2 || $user->data->user->data->IndustryRoleId == 3) {

					// 	if($user->data->user->get_user_address_details_relation->MobilePhone){
					// 		ob_start();
					// 		$opt['user_id'] = $user->data->user->data->Id;
					// 		$opt['mobile_phone'] = $user->data->user->get_user_address_details_relation->MobilePhone;
					// 		$opt['user_ip'] = $_SERVER['REMOTE_ADDR'];
					// 		$data = DM_Curl::HTTPPost($opt, 'resend-mobile-otp');
					// 		$request = json_decode($data);

					// 		$user_id = $user->data->user->data->Id;
					// 		$mobile_number = $user->data->user->get_user_address_details_relation->MobilePhone;
					// 		include DM_ABSPATH . '/template/auth/user/step/otp_verify.php';
					// 		$response['broker'] 		= ob_get_clean();
					// 		$response['IsNotNewUser'] 	= 1;
					// 		$response['type'] 	= 'success';
					// 		$response['otp'] 	= 1;
					// 		$response['caType'] 	= $_POST['caType'];
					// 		$response['press_release'] 	= $_POST['press_release'];
					// 	}else{
					// 		echo 's';
					// 		die;
					// 	}

					// } else {

						if (isset($_POST['press_release']) && $_POST['press_release'] == 'press_release') {
							$pageViewData = array(
								'id' => $property_id,
								'ip' => $_SERVER['REMOTE_ADDR'],
								'device' => $device
							);
							$data_view  = DM_Curl::HTTPPost($pageViewData, 'page-view', true, $user->access_token, array());

							if ($user->press_release->IsPressReleaseFile == 1) {

								$upload_dir   	= wp_upload_dir();
								$name 			= $user->press_release->FileName;
								if (!file_exists($upload_dir['basedir'] . '/datum')) {
									mkdir($upload_dir['basedir'] . '/datum', 0777, true);
								}
								if (!file_exists($upload_dir['basedir'] . '/datum/press_release')) {
									mkdir($upload_dir['basedir'] . '/datum/press_release', 0777, true);
								}

								chmod($upload_dir['basedir'] . '/datum/press_release/', 0777);

								$url 		= $user->press_release->PressReleaseFile;
								$file_path 	= $upload_dir['basedir'] . '/datum/press_release/' . $name;
								$flpath = $upload_dir['basedir'] . '/datum/press_release/';

								exec('wget  -P "' . $flpath . '" "' . $url . '"');
								chmod($file_path, 0777);

								$name = str_replace('_', ' ', $name);
								rename($file_path, $upload_dir['basedir'] . '/datum/press_release/' . $name);
								$file_URL = $upload_dir['baseurl'] . '/datum/press_release/' . $name;

								$response = array(
									'type' 	=> 'success',
									'press_release_type'	=> 1,
									'is_press_release'	=> 1,
									'pp_link'	=> $file_URL,
									'pp_name'	=> $name,
								);
							} else {
								$response = array(
									'type' 	=> 'success',
									'press_release_type'	=> 1,
									'is_press_release'	=> 0,
									'pp_link'	=> $user->press_release->PressReleaseLink,
								);
							}
						} else {
							if (isset($_POST['favProperty']) && $_POST['favProperty'] == 'favProperty') {
								$favoriteArray = array(
									'user_id' => $datum_user->Id,
									'property_id' => getDMPropertyId()
								);
								$favorite = DM_Curl::HTTPPost($favoriteArray, 'favorite', true, $user->access_token);
								$favorite = json_decode($favorite);
								if (isset($_POST['favProperty']) && $_POST['favProperty'] != '') {
									$favoriteFlag['property_id'] = $property_id;
								}
								$favoritesStatus = '';
								if ($favorite->status == 'success') {
									if ($favorite->data->favorite) {
										$favoriteFlag['favrite'] = true;
										$favoriteFlag['remove_favrite'] = false;
										$favoriteFlag['popup'] = false;
									} else {
										$favoriteFlag['favrite'] = false;
										$favoriteFlag['remove_favrite'] = true;
										$favoriteFlag['popup'] = false;
									}
								}
								$response = array(
									'type' 	=> 'success',
									'html'	=> ob_get_clean(),
									'IsAccountVerified'	=> 1,
									'favorite' => $favoriteFlag
								);
							} else {
								ob_start();
								$show = false;
								$html = '';
								$postData 	 = array(
									'propertyId' 		=> $property_id,
									'user_ip'	 		=> $_SERVER['REMOTE_ADDR'],
									'documentType'		=> ($_POST['caType']) ? $_POST['caType'] : '',
									'page_view_count'	=> '1',
									'timezon' => ($_POST['timezon']) ? $_POST['timezon'] : '',
								);
								if (isset($_POST['direct_login']) && $_POST['direct_login'] == 'Yes') {

									$response = array(
										'type' 	=> 'success',
										'html'	=> ob_get_clean(),
										'IsAccountVerified'	=> 1,
										//'IsNotNewUser'	=> $user->IsNotNewUser,
										'property_id' => ''
									);
								} else {
									if (isset($_POST['caType']) && $_POST['caType'] != '') {
										$filesNotFound = 1;
										$checkCaSign = DM_Curl::HTTPPost($postData, 'property-docoument-list', true, $user->access_token);
										$agreementData = json_decode($checkCaSign);
										if ($agreementData->status == 'failed') {
											include DM_ABSPATH . '/template/auth/no-popuphtml.php';
										} else {
											switch ($agreementData->type) {
												case 'agreement':
													include DM_ABSPATH . '/template/auth/agreement.php';
													break;
												case 'Approved':
													$html = $agreementData->html;
													$type = $_POST['caType'];
													include DM_ABSPATH . '/template/auth/document_vault_structure.php';
													break;
												case 'agreement_success':
													$show = true;
													include DM_ABSPATH . '/template/auth/agreement.php';
													break;
												case 'Rejected':
													include DM_ABSPATH . '/template/auth/om-reject-message.php';
													break;
												case 'OmRequested':
													include DM_ABSPATH . '/template/auth/OmRequested.php';
													break;
												case 'ddrequested':
													include DM_ABSPATH . '/template/auth/ddalreadysended.php';
													break;
												case 'Pending':
												case 'Requested':
												case 'om-message-popup':
													include DM_ABSPATH . '/template/auth/om-message-popup.php';
													break;
												case 'agent-not-found':
													include DM_ABSPATH . '/template/auth/agent-not-found.php';
													break;
												case 'agent-not-found':
													include DM_ABSPATH . '/template/auth/agent-not-found.php';
													break;
												case 'OmRequestednotsedndd':
													include DM_ABSPATH . '/template/auth/omalreadysended.php';
													break;
												case 'DD':
													if ($agreementData->status == "success") {
														if (!empty($agreementData->data)) {
															if ($agreementData->data->DuediligenceRequestStatus == 2) {
																include DM_ABSPATH . '/template/auth/dd_success.php';
															} elseif ($agreementData->data->DuediligenceRequestStatus == 3) {
																$high_security = false;

																if (isset($agreementData->high_security) && $agreementData->high_security) {
																	$high_security = true;
																}
																if (isset($agreementData->dddocflag)) {
																	$dddocflag = $agreementData->dddocflag;
																} else {
																	$dddocflag = false;
																}
																$type = $_POST['caType'];
																$html = $agreementData->html;
																include DM_ABSPATH . '/template/auth/document_vault_structure.php';
															} elseif ($agreementData->data->DuediligenceRequestStatus == 4) {
																include DM_ABSPATH . '/template/auth/dd_rejected.php';
															} else {
																include DM_ABSPATH . '/template/auth/due_diligence.php';
															}
														} else {
															include DM_ABSPATH . '/template/auth/due_diligence.php';
														}
													} else {
														include DM_ABSPATH . '/template/auth/no-popuphtml.php';
													}
													break;
												default:
													include DM_ABSPATH . '/template/auth/no-popuphtml.php';
													// code...
													break;
											}
										}

										if (isset($_POST['property_id']) && $_POST['property_id'] != "") {
											$response = array(
												'type' 	=> 'success',
												'html'	=> ob_get_clean(),
												'IsAccountVerified'	=> 1,
												//'IsNotNewUser'	=> $user->IsNotNewUser,
												'dd_html'	=> $html,
											);
										} else {
											$response = array(
												'type' 	=> 'success',
												'html'	=> ob_get_clean(),
												'IsAccountVerified'	=> 1,
												//'IsNotNewUser'	=> $user->IsNotNewUser,
												'property_id' => ''
											);
										}
									} else {



										$response = array(
											'type' 	=> 'success',
											'html'	=> ob_get_clean(),
											'IsAccountVerified'	=> 1,
											//'IsNotNewUser'	=> $user->IsNotNewUser,
											'property_id' => ''
										);
									}
								}
							}
						}
					//}
				}
			}
		}

		// if($user->data->user->data->IndustryRoleId == 2 && $user->IsNotNewUser == 1){	
		// 	ob_start();
		// 	$user_id = $user->data->user->data->Id;

		// 	include DM_ABSPATH . '/template/auth/user/step/Broker.php';

		// 	$response['broker'] 		= ob_get_clean();
		// 	$response['IsNotNewUser'] 	= 1;


		// }

		wp_send_json_success($response);
		wp_die();
	}

	public function otp_verify($value = '')
	{
		$_POST['user_ip'] = $_SERVER['REMOTE_ADDR'];
		$data = DM_Curl::HTTPPost($_POST, 'verify-email-otp');
		$user = json_decode($data);

		if ($user->status == 'success') {
			$response = array(
				'type' 	=> 'success',
			);
		} else {
			$response = array(
				'type' 	=> 'failure',
				'html'	=> $user->message
			);
		}
		wp_send_json_success($response);
		wp_die();
	}

	public function otp_resend()
	{
		$_POST['user_ip'] = $_SERVER['REMOTE_ADDR'];
		$data = DM_Curl::HTTPPost($_POST, 'resend-email-otp');
		$user = json_decode($data);

		if ($user->status == 'success') {
			$response = array(
				'type' 	=> 'success',
			);
		} else {

			$response = array(
				'type' 	=> 'failure',
				'html'	=> $errors,
				//'account'	=> $account,
			);
		}
		wp_send_json_success($response);
		wp_die();
	}

	public function forgot_password()
	{
		$_POST['user_ip'] = $_SERVER['REMOTE_ADDR'];
		$data = DM_Curl::HTTPPost($_POST, 'forgot-password');
		
		$user = json_decode($data);

		if ($user->status == 'success') {
			global $auth;
			$auth = $user->data;
			ob_start();
			switch ($user->step) {
				case '1':
					include DM_ABSPATH . '/template/auth/forgot/authentication.php';
					break;
				case '2':
					include DM_ABSPATH . '/template/auth/forgot/create_new_password.php';
					break;
				case '3':

					break;

				default:
					// code...
					break;
			}
			$response = array(
				'type' 	=> 'success',
				'html'	=> ob_get_clean(),
			);
		} else {
			$response = array(
				'type' 	=> 'failure',
				'html'	=> $user->message
			);
		}
		wp_send_json_success($response);
		wp_die();
	}

	public function Onetime_password()
	{
		$_POST['user_ip'] = $_SERVER['REMOTE_ADDR'];
		$data = DM_Curl::HTTPPost($_POST, 'verify-onetime-password');
		$user = json_decode($data);

		if ($user->status == 'success') {
			global $auth;
			$auth = $user->data;

			ob_start();
			include DM_ABSPATH . '/template/auth/forgot/create_new_password.php';
			$response = array(
				'type' 	=> 'success',
				'html'	=> ob_get_clean(),
				'remove_resend' => $auth->remove_resend
			);
		} else {
			$response = array(
				'type' 	=> 'failure',
				'html'	=> $user->message,
				'remove_resend' => $user->remove_resend
			);
		}
		wp_send_json_success($response);
		wp_die();
	}

	public function forgot_change_password()
	{
		$_POST['user_ip'] = $_SERVER['REMOTE_ADDR'];
		$data = DM_Curl::HTTPPost($_POST, 'reset-password');
		$user = json_decode($data);
		if ($user->status == 'success') {
			$cookie_name 	= "access_token";
			$cookie_value 	= $user->data->access_token;
			setcookie($cookie_name, $cookie_value, time() + 86400, "/");
			$response = array(
				'type' 	=> 'success',
				'html'	=> $user->message,
				'access_token' => $user->data->access_token,
				'redirect_url' => home_url()
			);
		} else {
			$response = array(
				'type' 	=> 'failure',
				'html'	=> $user->message
			);
			if (isset($user->data->user->IsAccountVerified) && !$user->data->user->IsAccountVerified) {
				$response['verify'] = false;
			}
		}
		wp_send_json_success($response);
		wp_die();
	}



	public function popuphtml()
	{
		ob_start();

		$favoriteFlag = [];
		$favoriteFlag['favrite'] = '';
		$favoriteFlag['remove_favrite'] = '';
		$favoriteFlag['popup'] = true;
		$favoriteFlag['login'] = false;
		$dd_html = '';
		$agreement_profile = 0;
		if ($_POST['popuphtml']) {
			switch ($_POST['popuphtml']) {
				case 'login_new_html':

					break;
				case 'login_html':
					//unset($_COOKIE['access_token']);
					if (isset($_COOKIE['access_token']) && $_COOKIE['access_token'] != '') {

						global $datum_user, $single_property, $documenttype, $criteria, $high_security, $dddocflag;
						$property_id = $_POST['property_id'];
						$id = "get-property/" . $property_id . "/0";
						$data = DM_Curl::HTTPGet($id);
						$property = json_decode($data);
						if ($property->status != "failed") {
							$single_property = $property->data;

							$data = DM_Curl::HTTPGet('user');
							$datum_user = json_decode($data);

							if (isset($_POST['pageView']) && $_POST['pageView'] == 'Yes') {
								if (!empty($datum_user) && isset($datum_user->Id)) {
									$response = array(
										'type' 				=> 'success',
										'html'				=> ob_get_clean(),
										'page_referesh'     => true
									);
									wp_send_json_success($response);
									wp_die();
								}
							}

							if ($datum_user->status == 'failed') {
								include DM_ABSPATH . '/template/auth/login.php';
							} else if ($datum_user->isNextUpdateDate != '') {
								include DM_ABSPATH . '/template/auth/1031updateprofile.php';
							} else if ($datum_user->IsContactCreatedByDashboard && $datum_user->NextUpdateDate == "") {
								$data_new 		= DM_Curl::HTTPGet('acquisitioncriteria');
								$criteria 		= json_decode($data_new);
								include DM_ABSPATH . '/template/auth/1031updateprofile.php';
							} else {
								$show = false;
								$postData 	 = array(
									'propertyId' 	=> $_POST['property_id'],
									'user_ip'	 	=> $_SERVER['REMOTE_ADDR'],
									'documentType'	=> $_POST['caType'],
									'timezon' => ($_POST['timezon']) ? $_POST['timezon'] : '',
									//'listing'		=> $_POST['listing']

								);
								if (isset($_POST['listing']) && $_POST['listing'] == '1') {
									$agreement_profile = 1;
								}

								$filesNotFound = 1;

								$checkCaSign = DM_Curl::HTTPPost($postData, 'property-docoument-list');
								
								$agreementData = json_decode($checkCaSign);

								if ($agreementData->status == 'failed') {
									include DM_ABSPATH . '/template/auth/no-popuphtml.php';
								} else {
									switch ($agreementData->type) {
										case 'agreement':
											include DM_ABSPATH . '/template/auth/agreement.php';
											break;
										case 'Approved':
											$html = $agreementData->html;
											$type = $_POST['caType'];
											include DM_ABSPATH . '/template/auth/document_vault_structure.php';
											break;
										case 'agreement_success':
											$show = true;
											include DM_ABSPATH . '/template/auth/agreement.php';
											break;
										case 'Rejected':
											include DM_ABSPATH . '/template/auth/om-reject-message.php';
											break;
										case 'OmRequested':
											include DM_ABSPATH . '/template/auth/OmRequested.php';
											break;
										case 'ddrequested':
											include DM_ABSPATH . '/template/auth/ddalreadysended.php';
											break;
										case 'Pending':
										case 'Requested':
										case 'om-message-popup':
											include DM_ABSPATH . '/template/auth/om-message-popup.php';
											break;
										case 'agent-not-found':
											include DM_ABSPATH . '/template/auth/agent-not-found.php';
											break;
										case 'agent-not-found':
											include DM_ABSPATH . '/template/auth/agent-not-found.php';
											break;
										case 'OmRequestednotsedndd':
											include DM_ABSPATH . '/template/auth/omalreadysended.php';
											break;
										case 'DD':
											if ($agreementData->status == "success") {
												if (!empty($agreementData->data)) {
													if ($agreementData->data->DuediligenceRequestStatus == 2) {
														include DM_ABSPATH . '/template/auth/dd_success.php';
													} elseif ($agreementData->data->DuediligenceRequestStatus == 3) {

														$high_security = false;

														if (isset($agreementData->high_security) && $agreementData->high_security) {
															$high_security = true;
														}
														if (isset($agreementData->dddocflag)) {
															$dddocflag = $agreementData->dddocflag;
														} else {
															$dddocflag = false;
														}

														$type = $_POST['caType'];
														$html = $agreementData->html;
														include DM_ABSPATH . '/template/auth/document_vault_structure.php';
													} elseif ($agreementData->data->DuediligenceRequestStatus == 4) {
														include DM_ABSPATH . '/template/auth/dd_rejected.php';
													} else {
														include DM_ABSPATH . '/template/auth/due_diligence.php';
													}
												} else {
													include DM_ABSPATH . '/template/auth/due_diligence.php';
												}
											} else {
												include DM_ABSPATH . '/template/auth/no-popuphtml.php';
											}
											break;
										default:
											include DM_ABSPATH . '/template/auth/no-popuphtml.php';
											// code...
											break;
									}
								}
							}
						} else {
							$favoriteFlag['popup'] = false;
							$favoriteFlag['reload'] = true;
						}
					} else {

						global $single_property, $secirityRoleType;
						$property_id = $_POST['property_id'];
						$id = "get-property/" . $property_id . "/0";
						$data = DM_Curl::HTTPGet($id);
						$property = json_decode($data);
						$single_property = $property->data;
						if (isset($_POST['caType']) && $_POST['caType'] == "") {
							set_transient('direct_login', true, 86400);
						} else {
							$secirityRoleType = $_POST['caType'];
						}
						include DM_ABSPATH . '/template/auth/login.php';
					}
					break;
				case 'register_html':
					global $criteria;
					//$_COOKIE['access_token'] = '';
					$data_new 		= DM_Curl::HTTPGet('acquisitioncriteria');
					$criteria 		= json_decode($data_new);

					if (isset($_COOKIE['access_token']) && $_COOKIE['access_token'] != '') {
						global $datum_user;
						$data = DM_Curl::HTTPGet('user');
						$datum_user = json_decode($data);
						include DM_ABSPATH . '/template/auth/user/updateprofile.php';
					} else {
						include DM_ABSPATH . '/template/auth/user/createAccount.php';
						//include DM_ABSPATH . '/template/auth/verify.php';
					}
					break;
				case 'register_new_html':
					global $criteria;
					global $datum_user;

					$config = [
						'callback' => home_url(),
						'providers' => [
							'LinkedIn' => [
								'enabled' => true,
								'keys' => [
									'id' => '7848fcb29l5sna',
									'secret' => 'UNUsWqRREMayzqsV',
								],
								"scope"   => "r_liteprofile r_emailaddress",
							],
						]
					];

					$hybridauth     = new Hybridauth($config);
					$adapter        = $hybridauth->authenticate('LinkedIn');

					$userData 		= $adapter->getUserProfile();

					$array = array(
						'email' 		=> $userData->email,
						'LinkedinImage'	=> $userData->photoURL,
						'firstName'		=> $userData->firstName,
						'lastName'		=> $userData->lastName,
						'country'		=> $userData->country,
						'Title'			=> $userData->displayName,
						'city'			=> $userData->city,
						'zip'			=> $userData->zip,
						'social' 		=> 'LinkedIn',
						'user_agent'	=> $_SERVER['HTTP_USER_AGENT'],
						'user_ip'		=> $_SERVER['REMOTE_ADDR'],
					);


					$data      = DM_Curl::HTTPPost($array, 'new-user-register');

					$request   = json_decode($data);


					$datum_user = $request->data;

					
					$data_new 		= DM_Curl::HTTPGet('acquisitioncriteria');

					$criteria 		= json_decode($data_new);
					$email 			= $datum_user->email;

					$adapter = $hybridauth->getAdapter('LinkedIn');
					$adapter->disconnect();

					if ($request->status == 'success') {
						$email_error 	 = false;
						include DM_ABSPATH . '/template/auth/user/registerlinkedinprofile.php';
					} else {
						$email_error = true;
						include DM_ABSPATH . '/template/auth/user/createAccount.php';
					}

					$response = array(
						'type' 				=> 'success',
						'html'				=> ob_get_clean(),
						'email'				=> $social_email,
						'user_id'			=> $datum_user->Id,
						'favorite' 			=> $favoriteFlag,
					);
					wp_send_json_success($response);
					wp_die();
					break;
				case 'forgot':
					include DM_ABSPATH . '/template/auth/forgot.php';
					break;
				case 'dashboard_verification_login':
					include DM_ABSPATH . '/template/auth/dashboard_verification_login.php';
					break;
				case 'dashboard_verification_logout':
					include DM_ABSPATH . '/template/auth/dashboard_verification_flow_logout.php';
					break;
				case 'due_diligence':
					if (isset($_POST['listing']) && $_POST['listing'] == '1') {
						$agreement_profile = 1;
					}

					global $wpdb, $datum_user, $single_property, $documenttype, $criteria;
					$property_id = $_POST['property_id'];
					$id = "get-property/" . $property_id . "/0";
					$data = DM_Curl::HTTPGet($id);
					$property = json_decode($data);
					$single_property = $property->data;
					$data = DM_Curl::HTTPGet('user');
					$datum_user = json_decode($data);
					$type = 'Due Diligence';

					if (!empty($datum_user) && $datum_user->status == 'failed') {
						set_transient('under_contract_dd', true, 86400);
						include DM_ABSPATH . '/template/auth/login.php';
					} else {

						if ($datum_user->IsupdateDashbord) {

							$upload 	= wp_upload_dir();
							$data_new 		= DM_Curl::HTTPGet('acquisitioncriteria');
							$criteria 		= json_decode($data_new);
							include DM_ABSPATH . '/template/auth/1031updateprofile.php';
						} else if ($datum_user->isNextUpdateDate) {

							$upload 	= wp_upload_dir();
							$data_new 		= DM_Curl::HTTPGet('acquisitioncriteria');
							$criteria 		= json_decode($data_new);
							include DM_ABSPATH . '/template/auth/1031updateprofile.php';
						} else {

							$postData = array(
								'property_id' 	=> $property_id,
								'user_ip' 		=> $_SERVER['REMOTE_ADDR']
							);
							$ddRequest = DM_Curl::HTTPPost($postData, 'check-dd-request');

							$ddRequest = json_decode($ddRequest);
							if ($ddRequest->status == "success") {
								if (!empty($ddRequest->data)) {
									if ($ddRequest->data->DuediligenceRequestStatus == 2) {
										include DM_ABSPATH . '/template/auth/dd_success.php';
									} elseif ($ddRequest->data->DuediligenceRequestStatus == 3) {
										$html = $ddRequest->html;
										include DM_ABSPATH . '/template/auth/document_vault_structure.php';
									} elseif ($ddRequest->data->DuediligenceRequestStatus == 4) {
										include DM_ABSPATH . '/template/auth/dd_rejected.php';
									} else {
										include DM_ABSPATH . '/template/auth/due_diligence.php';
									}
								} else {
									include DM_ABSPATH . '/template/auth/due_diligence.php';
								}
							} else {
								include DM_ABSPATH . '/template/auth/no-popuphtml.php';
							}
						}
					}
					break;
				case 'favorite_popup':
					global $wpdb, $single_property, $datum_user;
					$data = DM_Curl::HTTPGet('user');
					$datum_user = json_decode($data);
					$property_id = $_POST['property_id'];

					if (isset($_POST['pageView']) && $_POST['pageView'] == 'Yes') {
						if (!empty($datum_user) && isset($datum_user->Id)) {
							$response = array(
								'type' 				=> 'success',
								'html'				=> ob_get_clean(),
								'page_referesh'     => true
							);
							wp_send_json_success($response);
							wp_die();
						}
					}

					if ($datum_user->IsupdateDashbord && $datum_user->NextUpdateDate == "") {
						global $criteria;
						$upload 	= wp_upload_dir();
						$data_new 		= DM_Curl::HTTPGet('acquisitioncriteria');
						$criteria 		= json_decode($data_new);
						ob_start();
						include DM_ABSPATH . '/template/auth/1031updateprofile.php';
						$response = array(
							'type' 				=> 'success',
							'html'				=> ob_get_clean(),
							'isNextUpdateDate'	=> 1,
							'update_profile' => true
						);
						wp_send_json_success($response);
						wp_die();
					} else {
						if ($datum_user->status == 'failed') {
							include DM_ABSPATH . '/template/auth/login.php';
							$favoriteFlag['favrite'] = '';
							$favoriteFlag['remove_favrite'] = '';
							$favoriteFlag['popup'] = true;
							$favoriteFlag['login'] = true;
							if (isset($_POST['favProperty']) && $_POST['favProperty'] != '') {
								$favoriteFlag['favProperty'] = $_POST['favProperty'];
								$favoriteFlag['property_id'] = $property_id;
							}
							$favoriteFlag['favProperty'] = 'property';
							$favoriteFlag['property_id'] = $property_id;
						} else {
							if (isset($_POST['property_id']) && $_POST['property_id'] != '') {
								if (isset($_POST['favProperty']) && $_POST['favProperty'] != '') {
									$favoriteFlag['property_id'] = $_POST['property_id'];
								}
								$favoriteArray = array(
									'user_id' => $datum_user->Id,
									'property_id' => $_POST['property_id']
								);

								$favorite = DM_Curl::HTTPPost($favoriteArray, 'favorite');
								$favorite = json_decode($favorite);

								if ($favorite->status == 'success') {
									if ($favorite->data->favorite) {
										$favoriteFlag['favrite'] = true;
										$favoriteFlag['remove_favrite'] = '';
										$favoriteFlag['popup'] = false;
										$favoriteFlag['property_id'] = $_POST['property_id'];
									} else {
										$favoriteFlag['favrite'] = '';
										$favoriteFlag['remove_favrite'] = true;
										$favoriteFlag['popup'] = false;
										$favoriteFlag['property_id'] = $_POST['property_id'];
									}
								}
							}
						}
					}
					break;
				case 'favorite_my_listing':
					global $wpdb, $single_property, $datum_user;
					$data = DM_Curl::HTTPGet('user');
					$datum_user = json_decode($data);
					$favoriteArray = array(
						'user_id' 		=> getDMUserId(),
						'property_id' 	=> $_POST['property_id']
					);

					$favorite = DM_Curl::HTTPPost($favoriteArray, 'favorite');
					$favorite = json_decode($favorite);
					if ($favorite->status == 'success') {
						$data = DM_Curl::HTTPPost('', 'get-favorite-property', true, '');
						$favritesProperty = json_decode($data);
						$favritesProperty = $favritesProperty->data->data;
						include DM_ABSPATH . '/template/mylisting/favritesProperty.php';
					} else {
						$response = array(
							'type' 	=> 'failure',
							'html'	=> $favorite->errors
						);
					}

					break;
				case 'advanced_search':
					global $wpdb, $property_type_subtyep, $property_status, $property_tenancy, $property_building_class, $property_location;
					$property_commons = DM_Curl::HTTPGet('property_commons');
					$property_commons = json_decode($property_commons);

					if ($property_commons->status == 'success') {
						$property_type_subtyep = $property_commons->data->property_type_sub;
						$property_status = $property_commons->data->property_status;
						$property_tenancy = $property_commons->data->property_tenancy;
						$property_building_class = $property_commons->data->property_building_class;
						$property_location = $property_commons->data->property_location;
					}
					$data_new 		= DM_Curl::HTTPGet('acquisitioncriteria');
					$criteria 	= json_decode($data_new);

					include DM_ABSPATH . '/template/advanced_search.php';
					break;
				case 'change_password_popup':
					include DM_ABSPATH . '/template/auth/change-password.php';
					break;
				case 'request_info':
					global $wpdb, $single_property, $datum_user, $userLoggedInd;
					$userLoggedInd = false;
					$property_id = $_POST['property_id'];
					$id = "get-property/" . $property_id . "/0";
					$data = DM_Curl::HTTPGet($id);
					$property = json_decode($data);
					$single_property = $property->data;
					if (isset($_COOKIE['access_token']) && $_COOKIE['access_token'] != '') {
						$userLoggedInd = true;
						$data = DM_Curl::HTTPGet('user');
						$datum_user = json_decode($data);
					} else {
						$userLoggedInd = true;
					}

					include DM_ABSPATH . '/template/request_info.php';
					break;
				case 'reset_password':
					global $reset_token;
					if (isset($_POST['resetPasswordToken']) && $_POST['resetPasswordToken'] != "") {
						$reset_token = $_POST['resetPasswordToken'];
					}

					include DM_ABSPATH . '/template/auth/reset-password.php';
					break;
				case 'contact_from':
					global $single_property;
					$id = "get-property/" . $_POST['property_id'] . '/0';
					$data = DM_Curl::HTTPGet($id);
					$property = json_decode($data);
					$single_property = $property->data;
					include DM_ABSPATH . '/template/auth/contact_from.php';
					break;
				case 'share_property':
					global $single_property;
					$id = "get-property/" . $_POST['property_id'] . '/0';
					$data = DM_Curl::HTTPGet($id);
					$property = json_decode($data);
					$single_property = $property->data;
					include DM_ABSPATH . '/template/auth/share_property.php';
					break;
				case 'insights_property':
					global $single_insight;
					$data = DM_Curl::HTTPPost(array('insight_id' => $_POST['property_id']), 'insight-page');
					
					$insight = json_decode($data);
					
					$single_insight = $insight->data;
					include DM_ABSPATH . '/template/auth/insight_property.php';
					break;
				default:
					# code...
					break;
			}
		}
		$response = array(
			'type' 	=> 'success',
			'html'	=> ob_get_clean(),
			'favorite' => $favoriteFlag,
			'dd_html'	=> $html,
		);

		wp_send_json_success($response);
		wp_die();
	}

	public function document_vault_structure()
	{
		global $wpdb, $datum_user, $single_property, $documenttype;
		ob_start();
		$file_path = '';
		$name = '';
		$html = '';
		$file_URL = '';
		$upload_dir   	= wp_upload_dir();
		$documenttype = $_POST['documenttype'];


		if ($_POST['documenttype'] != '') {

			$document_vault_structure = DM_Curl::HTTPPost(
				array(
					'propertyId' 	=> $_POST['property_id'],
					'user_ip'	 	=> $_SERVER['REMOTE_ADDR'],
					'copyOnEmail'	=> $_POST['copyOnEmail'],
					'downloadCA'	=> '1',
					'documentType'	=> $_POST['documenttype'],
					'agreement_profile'		=> $_POST['agreement_profile'],
					'timezon' => ($_POST['timezon']) ? $_POST['timezon'] : "",
				),
				'property-vault-list'
			);

			$document_vault_structure = json_decode($document_vault_structure);

			if ($document_vault_structure->downloadCA->URL  != '') {
				$upload_dir   	= wp_upload_dir();
				$name 			= $document_vault_structure->downloadCA->FileName;

				if (!file_exists($upload_dir['basedir'] . '/datum')) {
					mkdir($upload_dir['basedir'] . '/datum', 0777, true);
				}

				if (!file_exists($upload_dir['basedir'] . '/datum/ca')) {
					mkdir($upload_dir['basedir'] . '/datum/ca', 0777, true);
				}
				chmod($upload_dir['basedir'] . '/datum/ca/', 0777);

				$url 		= $document_vault_structure->downloadCA->URL;

				$file_path 	= $upload_dir['basedir'] . '/datum/ca/' . $name;

				file_put_contents($file_path, file_get_contents($url));
				chmod($file_path, 0777);

				$name = str_replace('_', ' ', $name);

				rename($file_path, $upload_dir['basedir'] . '/datum/ca/' . $name);

				$file_URL = $upload_dir['baseurl'] . '/datum/ca/' . $name;
			}

			$property_id = $_POST['property_id'];
			$id = "get-property/" . $property_id . "/0";
			$data = DM_Curl::HTTPGet($id);

			$property = json_decode($data);
			$single_property = $property->data;

			if (isset($document_vault_structure->type) && $document_vault_structure->type != '') {
				switch ($document_vault_structure->type) {
					case 'Approved':
						$html = $document_vault_structure->html;
						$prevType = '';
						$type = $_POST['documenttype'];
						if (isset($_POST['preRole']) && $_POST['preRole'] != "") {
							$prevType = $_POST['preRole'];
						} else {
							$prevType = $_POST['documenttype'];
						}
						include DM_ABSPATH . '/template/auth/document_vault_structure.php';
						break;
					case 'Pending':
					case 'Requested':
					case 'agreement_success':
						include DM_ABSPATH . '/template/auth/om-message-popup.php';
						break;
					case 'reject':
						include DM_ABSPATH . '/template/auth/om-reject-popup.php';
						break;
					case 'OmRequested':
						include DM_ABSPATH . '/template/auth/OmRequested.php';
						break;
					case 'agent-not-found':
						include DM_ABSPATH . '/template/auth/agent-not-found.php';
						break;
					case 'DD':
						if ($document_vault_structure->status == "success") {
							if (!empty($document_vault_structure->data)) {
								if ($document_vault_structure->data->DuediligenceRequestStatus == 2) {
									include DM_ABSPATH . '/template/auth/dd_success.php';
								} elseif ($document_vault_structure->data->DuediligenceRequestStatus == 3) {
									$html = $document_vault_structure->html;
									$type = $_POST['documenttype'];
									include DM_ABSPATH . '/template/auth/document_vault_structure.php';
								} elseif ($document_vault_structure->data->DuediligenceRequestStatus == 4) {
									include DM_ABSPATH . '/template/auth/dd_rejected.php';
								} else {
									include DM_ABSPATH . '/template/auth/due_diligence.php';
								}
							} else {
								include DM_ABSPATH . '/template/auth/due_diligence.php';
							}
						} else {
							include DM_ABSPATH . '/template/auth/no-popuphtml.php';
						}
						break;
					default:
						break;
				}
			}
		} else {
			include DM_ABSPATH . '/template/auth/document_vault_structure.php';
		}

		$response = array(
			'type' 	=> 'success',
			'html'	=> ob_get_clean(),
			'URL' 	=> $file_URL,
			'basename' => $name,
			'dd_html'	=> $html,
		);
		wp_send_json_success($response);
		wp_die();
	}

	public function download_document_valut()
	{
		$_POST['user_ip']	= $_SERVER['REMOTE_ADDR'];
		if ((isset($_POST['type']) && $_POST['type'] != "") && $_POST['type'] == 'Offering Memorandum' || $_POST['type'] == 'Due Diligence' || $_POST['type'] == 'Public') {

			global $single_property;
			$property_id = $_POST['property_id'];
			$id = "get-property/" . $property_id . "/0";
			$data = DM_Curl::HTTPGet($id);

			$property = json_decode($data);
			$single_property = $property->data;
			$propertySlug = $single_property->URLSlug;
			$data = DM_Curl::HTTPGet('user');
			$datum_user = json_decode($data);
			$currentUserId = $datum_user->Id;
			$main_path = wp_upload_dir()['basedir'] . '/download_document';
			$uploadsPath = wp_upload_dir()['baseurl'];
			if (!file_exists($main_path)) {
				mkdir($main_path, 0777, true);
			}

			if (!file_exists($main_path . '/' . $propertySlug)) {
				mkdir($main_path . '/' . $propertySlug, 0777, true);
			}

			if (!file_exists($main_path . '/' . $propertySlug . '/' . $currentUserId)) {
				mkdir($main_path . '/' . $propertySlug . '/' . $currentUserId, 0777, true);
			}

			$directoryFullPath = $main_path . '/' . $propertySlug . '/' . $currentUserId;
			$documentVaultSavedArray = [];
			$zipFileName = $propertySlug . '.zip';
			$documentBlobPath = DOCUMENT_VAULT_URL;
			$checkPostData = array(
				'property_id' => $_POST['property_id'],
				'type' => $_POST['type']
			);

			$accessData = DM_Curl::HTTPPost($checkPostData, 'check-sequrity-role-access');

			$accessData = json_decode($accessData);
			if (!empty($accessData) && isset($accessData->status) && $accessData->status == 'success') {
				if (!$accessData->access) {
					$response = array(
						'type' 		=> 'access_remove',
						'html'		=> "",
						'access' 	=> $accessData->access,
					);
					wp_send_json_success($response);
					wp_die();
				}
			}

			if (isset($_POST['filename']) && !empty($_POST['filename'])) {

				$fileArray = $_POST['filename'];
				$file_type = $_POST['type'];

				if ((array_key_exists('due_diligence', $fileArray)) && (array_key_exists('high', $fileArray))) {
					$fileArray1 = $fileArray['due_diligence'];
					$fileArray2 = $fileArray['high'];

					$fileArray = $fileArray1 + $fileArray2;
					$file_type = '';
				} elseif (array_key_exists('due_diligence', $fileArray)) {
					$fileArray = $fileArray['due_diligence'];
					$file_type = $_POST['type'];
				} elseif (array_key_exists('high', $fileArray)) {
					$fileArray = $fileArray['high'];
					$file_type = 'High';
				}

				if (sizeof($fileArray) == 1) {
					$fileName = "";
					$originalFileName = "";
					foreach ($fileArray as $key => $value) {
						$fileName = basename($value[0]);
						$tmpUrl = $documentBlobPath . '/' . $propertySlug . '/';
						$fullPathAzure = $tmpUrl . stripslashes($value[0]);
						$originalFileName = basename($fullPathAzure);
						$fileName = str_replace(' ', '_', $fileName);
						$content = file_put_contents($directoryFullPath . '/' . $fileName, file_get_contents(fileUrl($fullPathAzure)));
						$documentVaultSavedArray[] = array(
							'filename'        => $originalFileName,
							'directoryFileId' => $key,
							'file_type'       => $file_type
						);
					}

					$singleFileName = $uploadsPath . '/download_document/' . $propertySlug . '/' . $currentUserId . '/' . $fileName;
					$postArray = [];
					$postArray['property_id'] = $_POST['property_id'];
					$postArray['property_name'] = $_POST['property_name'];
					$postArray['agreement_profile'] = $_POST['agreement_profile'];
					$postArray['type'] = $_POST['type'];
					$postArray['user_ip'] = $_POST['user_ip'];
					$postArray['filename'] = $documentVaultSavedArray;
					$data = DM_Curl::HTTPPost($postArray, 'property-down-vault-list');
					$response = array(
						'type' 		=> 'success',
						'html'		=> "",
						'URL' 		=> $singleFileName,
						'filename' 	=> $fileName,
					);
					wp_send_json_success($response);
					wp_die();
				} else {

					$tmpUrl = $documentBlobPath . '/' . $propertySlug . '/';

					$downloadFilesArray = [];
					$downloadFilesArray['propertyurlslug'] = $propertySlug;
					$filesArrays = [];

					foreach ($fileArray as $key => $value) {

						if (isset($value[0]) && $value[0] != "") {

							$flUrl = $propertySlug . '/' . $value[0];

							$filesArrays[] = $flUrl;

							$documentVaultSavedArray[] = array(
								'filename' => basename($value[0]),
								'directoryFileId' => $key,
								'file_type' => explode('/', $value[0])[0]
							);
						}
					}

					$downloadFilesArray['filePaths'] = $filesArrays;
					$downloadFilesArray1 = stripslashes(json_encode($downloadFilesArray, JSON_UNESCAPED_UNICODE));

					$downloadData = DM_Curl::HTTPPostAzureFunction($downloadFilesArray1);

					$postArray = [];
					$postArray['property_id'] = $_POST['property_id'];
					$postArray['property_name'] = $_POST['property_name'];
					$postArray['agreement_profile'] = $_POST['agreement_profile'];
					$postArray['type'] = $_POST['type'];
					$postArray['user_ip'] = $_POST['user_ip'];
					$postArray['filename'] = $documentVaultSavedArray;
					$downloadData = json_decode($downloadData);

					$data = DM_Curl::HTTPPost($postArray, 'property-down-vault-list');
					if (isset($downloadData->isSucess) && $downloadData->isSucess) {
						$response = array(
							'type' 		=> 'success',
							'html'		=> "",
							'URL' => $downloadData->downloadlink,
							'filename' => basename($downloadData->downloadlink),
							'zip_file_delete' => 'delete'
						);
						wp_send_json_success($response);
						wp_die();
					} else {
						$response = array(
							'type' 		=> 'failure',
							'html'		=> "",
							'URL' => '',
							'filename' => '',
							'error_message' => 'Zip creation failed. Please try again'
						);
						wp_send_json_success($response);
						wp_die();
					}
				}
			}
		} else {
			$data = DM_Curl::HTTPPost($_POST, 'property-down-vault-list');

			$data = json_decode($data);

			if ($data->status == 'failed') {
				$response = array(
					'type' 		=> 'success',
					'html'		=> '',
					'URL' 		=> '',
					'filename' 	=> '',
				);
				wp_send_json_success($response);
				wp_die();
			} else {
				$upload_dir   	= wp_upload_dir();
				$name 			= $data->FileName;

				if (!file_exists($upload_dir['basedir'] . '/datum')) {
					mkdir($upload_dir['basedir'] . '/datum', 0777, true);
				}

				if (!file_exists($upload_dir['basedir'] . '/datum/ca')) {
					mkdir($upload_dir['basedir'] . '/datum/ca', 0777, true);
				}
				chmod($upload_dir['basedir'] . '/datum/ca/', 0777);

				$url 		= $data->URL;

				$file_path 	= $upload_dir['basedir'] . '/datum/ca/' . $name;

				file_put_contents($file_path, file_get_contents($url));
				chmod($file_path, 0777);

				$name = str_replace('_', ' ', $name);

				rename($file_path, $upload_dir['basedir'] . '/datum/ca/' . $name);

				$file_URL = $upload_dir['baseurl'] . '/datum/ca/' . $name;

				$response = array(
					'type' 		=> 'success',
					'html'		=> $data->html,
					'URL' 		=> $file_URL,
					'filename' 	=> $name,
				);
				wp_send_json_success($response);
				wp_die();
			}
		}
	}

	public function donwloaded_document_zip_delete()
	{
		if (isset($_POST['zipfile_name']) && $_POST['zipfile_name'] != "") {
			$data = DM_Curl::HTTPPost(array('zipfile_name' => $_POST['zipfile_name']), 'zip-file-removed');
		}
		$response = array(
			'type' 		=> 'success',
		);
		wp_send_json_success($response);
		wp_die();
	}

	public function dd_request()
	{
		$property_id = $_POST['property_id'];
		$send_dd = $_POST['send_dd'];
		$postData = array(
			'property_id' => $property_id,
			'docuement_role' => 'Due Diligence',
			'user_ip' => $_SERVER['REMOTE_ADDR'],
			'timezon' => ($_POST['timezon']) ? $_POST['timezon'] : '',
		);

		$data = DM_Curl::HTTPPost($postData, 'send-dd-request');
		$data = json_decode($data);
		if ($data->status == 'success') {
			ob_start();
			include DM_ABSPATH . '/template/auth/dd_success.php';
			$response = array(
				'type' 	=> 'success',
				'html'	=> ob_get_clean(),
				'message' => $data->message,
			);
			wp_send_json_success($response);
			wp_die();
		} else {
			$response = array(
				'type' 	=> 'failed',
				'html'	=> $data->message,
				'message' => $data->message,
			);
		}
		wp_send_json_success($response);
		wp_die();
	}

	public function omRequest()
	{
		$postData = array(
			'property_id'	 	=> $_POST['property_id'],
			'docuement_role' 	=> 'Offering Memorandum',
			'user_ip' 			=> $_SERVER['REMOTE_ADDR'],
			'timezon' 			=> ($_POST['timezon']) ? $_POST['timezon'] : '',
		);

		$data = DM_Curl::HTTPPost($postData, 'send-om-request');
		$data = json_decode($data);
		if ($data->status == 'success') {
			ob_start();
			include DM_ABSPATH . '/template/auth/om-message-popup.php';
			$response = array(
				'type' 	=> 'success',
				'html'	=> ob_get_clean(),
				'message' => $data->message,
			);
			wp_send_json_success($response);
			wp_die();
		} else {
			$response = array(
				'type' 	=> 'failed',
				'html'	=> $data->message,
				'message' => $data->message,
			);
		}
		wp_send_json_success($response);
		wp_die();
	}

	public function dd_success()
	{
		ob_start();
		global $message;
		if (isset($_POST['message']) && $_POST['message'] != "") {
			$message = $_POST['message'];
		}

		$response = array(
			'type' 	=> 'success',
			'html'	=> ob_get_clean(),
		);
		wp_send_json_success($response);
		wp_die();
	}

	public function changed_password()
	{
		$_POST['user_ip'] = $_SERVER['REMOTE_ADDR'];
		$data = DM_Curl::HTTPPost($_POST, 'change-password');
		
		$user = json_decode($data);

		$txt =  $data;
		$myfile = file_put_contents('logs.txt', $txt . PHP_EOL, FILE_APPEND | LOCK_EX);

		if ($user->status == 'success') {
			if (isset($_COOKIE['access_token']) && $_COOKIE['access_token'] != '') {
				global $datum_user;
				$data = DM_Curl::HTTPGet('user');
				$datum_user = json_decode($data);
				include DM_ABSPATH . '/template/auth/updateprofile.php';
			}

			$response = array(
				'type' 	=> 'success',
				'html'	=> ob_get_clean(),
			);
		} else {
			$response = array(
				'type' 	=> 'failure',
				'html'	=> $user->errors
			);
		}
		wp_send_json_success($response);
		wp_die();
	}

	public function request_info()
	{
		$_POST['user_ip'] = $_SERVER['REMOTE_ADDR'];
		$data = DM_Curl::HTTPPost($_POST, 'request-inquire');
		$request = json_decode($data);

		$myfile = file_put_contents('logs.txt', $txt . PHP_EOL, FILE_APPEND | LOCK_EX);

		if ($request->status == 'success') {
			$response = array(
				'type' 	=> 'success',
				'html'	=> $request->message,
			);
		} else {
			$response = array(
				'type' 	=> 'failure',
				'html'	=> $request->errors
			);
		}
		wp_send_json_success($response);
		wp_die();
	}
	public function datum_logout()
	{

		$_POST['user_agent'] 	= $_SERVER['HTTP_USER_AGENT'];
		$_POST['user_ip'] 		= $_SERVER['REMOTE_ADDR'];

		$data 	= DM_Curl::HTTPPost($_POST, 'logout');
		$logout = json_decode($data);

		if ($logout->status == 'success') {

			unset($_COOKIE['access_token']);
			setcookie('access_token', null, -1, '/');
			unset($_SESSION['HYBRIDAUTH::STORAGE']);
			$response = array(
				'type' 	=> 'success',
			);
		} else {
			$response = array(
				'type' 	=> 'failure',
				'html'	=> $errors
			);
		}

		wp_send_json_success($response);
		wp_die();
	}

	public function read_property_name()
	{
		$_POST['user_ip'] = $_SERVER['REMOTE_ADDR'];
		$data = DM_Curl::HTTPPost($_POST, 'read-property-name');
		$request = json_decode($data);

		if ($request->status == 'success') {
			$html = '<ul id="property-name">';
			if (!empty($request->data)) {
				foreach ($request->data as $value) {
					$html .= '<li>' . $value->name . '</li>';
				}
			}
			$html .= '</ul>';
			$response = array(
				'type' 	=> 'success',
				'html'	=> $html,
			);
		} else {
			$response = array(
				'type' 	=> 'failure',
				'html'	=> $request->errors
			);
		}
		wp_send_json_success($response);
		wp_die();
	}

	public function resend_email()
	{
		$_POST['user_ip'] = $_SERVER['REMOTE_ADDR'];
		$data = DM_Curl::HTTPPost($_POST, 'resend-email-verification');
		$request = json_decode($data);

		if ($request->status == 'success') {
			$cookie_name 	= "access_token";
			$cookie_value 	= $user->access_token;
			setcookie($cookie_name, $cookie_value, time() + 86400, "/");

			$response = array(
				'type' 	=> 'success',
				'html'	=> $request->message
			);
		} else {
			$response = array(
				'type' 	=> 'failure',
				'html'	=> $request->message
			);
		}
		wp_send_json_success($response);
		wp_die();
	}
	public function resend_email_otp()
	{
		$_POST['user_ip'] = $_SERVER['REMOTE_ADDR'];
		$data = DM_Curl::HTTPPost($_POST, 'resend-email-otp');

		$request = json_decode($data);

		if ($request->status == 'success') {
			$response = array(
				'type' 	=> 'success',
				'html'	=> $request->message
			);
		} else {
			$response = array(
				'type' 	=> 'failure',
				'html'	=> $request->message
			);
		}
		wp_send_json_success($response);
		wp_die();
	}
	public function update_email()
	{
		global $datum_user;
		$_POST['user_ip'] = $_SERVER['REMOTE_ADDR'];
		$data = DM_Curl::HTTPPost($_POST, 'change-email');

		$request = json_decode($data);

		if ($request->status == 'success') {
			$response = array(
				'type' 	=> 'success',
				'html'	=> $request->message,
				'email'	=> $_POST['email']
			);
		} else {
			$response = array(
				'type' 	=> 'failure',
				'html'	=> $request->errors
			);
		}
		wp_send_json_success($response);
		wp_die();
	}

	public function send_otp()
	{
		global $datum_user;
		if (!empty($_POST['mobile_phone'])) {
			$_POST['mobile_phone'] = str_replace('-', '', $_POST['mobile_phone']);
		}

		$account = 0;
		$verify_acc = 2;
		if (isset($_POST['otp']) && $_POST['otp'] != '') {
			$_POST['otp'] = str_replace('-', '', $_POST['otp']);
			$_POST['user_ip'] = $_SERVER['REMOTE_ADDR'];
			$data = DM_Curl::HTTPPost($_POST, 'verify-mobile-otp');

			$request = json_decode($data);
			$verify_acc = 1;
			if (isset($request->account) && $request->account == 1) {
				$account = '1';
			}
			if ($request->status == 'success') {
				$response = array(
					'type' 	=> 'success',
					'html'	=> $request->message,
					'account'	=> $account,
					//'account_verify' = true,
				);
			} else {
				if (empty($request->errors)) {
					$response = array(
						'type' 	=> 'failure',
						'html'	=> $request->message,
						'array'	=> '0',
						'account'	=> $account,
						'isDesabled' => isset($request->isDesabled) ? $request->isDesabled : false
					);
				} else {
					$response = array(
						'type' 	=> 'failure',
						'html'	=> $request->errors,
						'array'	=> '1',
						'account'	=> $account,
						'isDesabled' => isset($request->isDesabled) ? $request->isDesabled : false
					);
				}
			}
		} else {

			$_POST['user_ip'] = $_SERVER['REMOTE_ADDR'];
			$data = DM_Curl::HTTPPost($_POST, 'resend-mobile-otp');

			$request = json_decode($data);

			if (isset($request->account) && $request->account == 1) {
				$account = '1';
			}
			if ($request->status == 'success') {
				$response = array(
					'type' 	=> 'success',
					'html'	=> $request->message,
					'verify' => 2,
					'account'	=> $account
				);
			} else {
				if (empty($request->errors)) {
					$response = array(
						'type' 	=> 'failure',
						'html'	=> $request->message,
						'array'	=> '0',
						'account'	=> $account
					);
				} else {

					if (isset($request->name) && $request->name != '') {
						$errors = array('mobile_phone' => $request->errors[0]);
					} else {
						$errors = $request->errors;
					}

					$response = array(
						'type' 	=> 'failure',
						'html'	=> $errors,
						'array'	=> '1',
						'account'	=> $account
					);
				}
			}
		}
		$response['verify_acc'] = $verify_acc;
		wp_send_json_success($response);
		wp_die();
	}

	public function reset_password()
	{
		if (isset($_POST['reset_token']) && $_POST['reset_token'] != "") {
			$_POST['token'] = $_POST['reset_token'];
		}
		$_POST['user_ip'] = $_SERVER['REMOTE_ADDR'];
		$data = DM_Curl::HTTPPost($_POST, 'reset');
		$request = json_decode($data);

		if ($request->status == 'success') {
			$response = array(
				'type' 	=> 'success',
				'html'	=> $request->message,
			);
		} else {
			$response = array(
				'type' 	=> 'failure',
				'html'	=> $user->errors,
				'message' => $request->message
			);
		}
		wp_send_json_success($response);
		wp_die();
	}


	public function errorcheck($request = array())
	{
		if (empty($request->errors)) {
			$response = array(
				'type' 	=> 'failure',
				'html'	=> $request->message,
				'array'	=> '0',
			);
		} else {
			$response = array(
				'type' 	=> 'failure',
				'html'	=> $request->errors,
				'array'	=> '1',
			);
		}
		return $response;
	}

	public function press_release($request = array())
	{
		global $single_property, $press_release_attr;
		$_POST['user_ip'] = $_SERVER['REMOTE_ADDR'];

		$property_id = $_POST['property_id'];
		$id = "get-property/" . $property_id . "/0";
		$data = DM_Curl::HTTPGet($id);
		$property = json_decode($data);
		$single_property = $property->data;

		if (isset($_COOKIE['access_token']) && $_COOKIE['access_token'] != '') {
			$data = DM_Curl::HTTPGet('user');
			$datum_user = json_decode($data);
			if (!empty($datum_user) && (isset($datum_user->status) && $datum_user->status == 'failed')) {
				include DM_ABSPATH . '/template/auth/login.php';
				$response = array(
					'type' 	=> 'success',
					'html' 	=> ob_get_clean()
				);
			} else {
				$data 		= DM_Curl::HTTPPost($_POST, 'add-pressrelease');
				$request 	= json_decode($data);

				if ($request->status == 'success') {
					$upload_dir   	= wp_upload_dir();
					$name 			= $request->data->PressReleaseFile;

					if (!file_exists($upload_dir['basedir'] . '/datum')) {
						mkdir($upload_dir['basedir'] . '/datum', 0777, true);
					}

					if (!file_exists($upload_dir['basedir'] . '/datum/press_release')) {
						mkdir($upload_dir['basedir'] . '/datum/press_release', 0777, true);
					}

					chmod($upload_dir['basedir'] . '/datum/press_release/', 0777);

					$url 		= $request->FileURL;
					$file_path 	= $upload_dir['basedir'] . '/datum/press_release/' . $name;
					$flpath = $upload_dir['basedir'] . '/datum/press_release/';

					exec('wget  -P "' . $flpath . '" "' . $url . '"');
					chmod($file_path, 0777);

					$name = str_replace('_', ' ', $name);
					rename($file_path, $upload_dir['basedir'] . '/datum/press_release/' . $name);
					$file_URL = $upload_dir['baseurl'] . '/datum/press_release/' . $name;

					if ($request->data->IsPressReleaseFile == 1) {

						$response = array(
							'type' 	=> 'success',
							'press_release_type'	=> 1,
							'is_press_release'	=> 1,
							'pp_link'	=> $file_URL,
							'pp_name'	=> $name,
							'html' => '',
						);
					} else {

						$response = array(
							'type' 	=> 'success',
							'press_release_type'	=> 1,
							'is_press_release'	=> 0,
							'pp_link'	=> $request->data->PressReleaseLink,
							'html' => '',
						);
					}
				}
			}
		} else {
			$press_release_attr = 'press_release';
			ob_start();
			include DM_ABSPATH . '/template/auth/login.php';
			$response = array(
				'type' 	=> 'success',
				'html' 	=> ob_get_clean()
			);
		}
		wp_send_json_success($response);
		wp_die();
	}

	public function contact_form()
	{
		$_POST['user_ip'] = $_SERVER['REMOTE_ADDR'];
		$data 		= DM_Curl::HTTPPost($_POST, 'contact-property');
		
		$request 	= json_decode($data);
		if ($request->status == 'success') {
			$response = array(
				'type' 	=> 'success',
				'html' 	=> 'Message sent successfully',
			);
		} else {
			$response 	= errorcheck($request);
		}
		wp_send_json_success($response);
		wp_die();
	}

	public function share_property()
	{
		$_POST['user_ip'] = $_SERVER['REMOTE_ADDR'];
		$data 		= DM_Curl::HTTPPost($_POST, 'share-property');
		
		$request 	= json_decode($data);

		if ($request->status == 'success') {
			$response = array(
				'type' 	=> 'success',
				'html' 	=> 'Message sent successfully',
			);
		} else {
			$response 	= errorcheck($request);
		}
		wp_send_json_success($response);
		wp_die();
	}

	public function showing_user_detalis()
	{
		global $datum_user;
		$data = DM_Curl::HTTPGet('user', array());
		$datum_user = json_decode($data);
		ob_start();
		include DM_ABSPATH . '/template/auth/user_dropdown.php';

		$response = array(
			'type' 	=> 'success',
			'html' 	=> ob_get_clean()
		);
		wp_send_json_success($response);
		wp_die();
	}

	public function share_insights()
	{
		if (isset($_POST['insights_data']) && !empty($_POST['insights_data'])) {
			$_POST['insights_data'] = json_encode($_POST['insights_data']);
		}
		$_POST['user_ip'] = $_SERVER['REMOTE_ADDR'];
		$data       = DM_Curl::HTTPPost($_POST, 'insights-sharing-email');
		$request    = json_decode($data);

		if ($request->status == 'success') {
			$response = array(
				'type'  => 'success',
				'html'  => 'Message sent successfully',
			);
		} else {
			$response   = errorcheck($request);
		}
		wp_send_json_success($response);
		wp_die();
	}

	public function my_property_list()
	{
		global $datum_user, $mypropertylist, $nextPageId, $LoadmorFlag;
		$_POST['user_ip'] = $_SERVER['REMOTE_ADDR'];
		$nextPageURL = "";
		if (isset($_POST['next_page_id']) && !empty($_POST['next_page_id']) && $_POST['next_page_id'] != 0) {
			$nextPageURL = 'my-property-list?page=' . $_POST['next_page_id'];
		} else {
			$nextPageURL = 'my-property-list';
		}
		$data = DM_Curl::HTTPPost($_POST, $nextPageURL, true, '');

		$myproperty = json_decode($data);

		$mypropertylist = $myproperty->data->data;
		$nextPageId = 0;
		if ($myproperty->data->next_page_url != null && $myproperty->data->next_page_url != '' && $myproperty->data->next_page_url != null) {
			$queryParams = parse_url($myproperty->data->next_page_url, PHP_URL_QUERY);
			$queryParams = explode('=', $queryParams);
			$nextPageId = $queryParams[1];
			$LoadmorFlag = true;
		} else {
			$LoadmorFlag = false;
		}
		ob_start();
		include DM_ABSPATH . '/template/mylisting/lists.php';
		$response = array(
			'type' 	     => 'success',
			'html' 	     => ob_get_clean(),
			'nextpageid' => $nextPageId,
			'ladmorebtn' => $LoadmorFlag
		);
		wp_send_json_success($response);
		wp_die();
	}

	public function remove_faverites()
	{

		global $wpdb, $datum_user;
		$data = DM_Curl::HTTPGet('user');
		$datum_user = json_decode($data);
		$property_id = $_POST['property_id'];

		if ($datum_user != "" && !empty($datum_user) || $datum_user->status != 'failed') {
			$favoriteArray = array(
				'user_id' => $datum_user->Id,
				'property_id' => $property_id
			);

			$favorite = DM_Curl::HTTPPost($favoriteArray, 'favorite');
			$favorite = json_decode($favorite);

			if ($favorite->status == 'success') {
				$response = array(
					'type' 	=> 'success',
					'html' 	=> '',
				);
			} else {
				$response = array(
					'type' 	=> 'failed',
					'html' 	=> '',
				);
			}
		}
		wp_send_json_success($response);
		wp_die();
	}

	public function check_om_access_for_dd()
	{
		global $wpdb;

		$property_id = $_POST['property_id'];
		$id = "get-property/" . $property_id . "/0";
		$data = DM_Curl::HTTPGet($id);
		$property = json_decode($data);
		$single_property = $property->data;

		if ($property->status == 'success') {
			$response = array(
				'type' 	=> 'success',
				'property' => $single_property,
			);
		} else {
			$response = array(
				'type' 	=> 'failed',
				'property' => [],
			);
		}
		wp_send_json_success($response);
		wp_die();
	}
	public function resend_onetime_password()
	{

		global $wpdb;
		$_POST['user_ip'] = $_SERVER['REMOTE_ADDR'];
		$data 		= DM_Curl::HTTPPost($_POST, 'resend-onetime-password');
		$request 	= json_decode($data);

		if ($request->status == 'success') {
			$response = array(
				'type' 	=> 'success',
				'block' => $request->block,
				'html' 	=> '',
				'message' => $request->message,
				'email' => $request->data->Email
			);
		} else {
			$response = array(
				'type' 	=> 'failed',
				'block' => $request->block,
				'html' 	=> '',
				'message' => $request->message
			);
		}
		wp_send_json_success($response);
		wp_die();
	}

	public function page_view_count()
	{
		$useragent = $_SERVER['HTTP_USER_AGENT'];
		$device = 0;
		if (wp_is_mobile()) {
			$device = 1;
		}
		$id 		= "page-view/" . $_POST['page_view_count'];
		$array = array('id' => $_POST['page_view_count'], 'ip' => $_SERVER['REMOTE_ADDR'], 'device' => $device);
		$data_view  = DM_Curl::HTTPPost($array, 'page-view');
		$response = array(
			'type' 	=> 'success',
			//'block' => $request->block,
			'html' 	=> '',
			//'message' => $request->message
		);
		wp_send_json_success($response);
		wp_die();
	}

	public function is_dashboard_user_check()
	{
		$data = DM_Curl::HTTPGet('user');
		$request 	= json_decode($data);
		$response = array(
			'type' 	=> 'success',
			'isNextUpdateDate' => false,
		);
		if (isset($request->IsupdateDashbord) && $request->IsupdateDashbord) {
			$response['isNextUpdateDate'] = true;
		} else {
			$response['isNextUpdateDate'] = false;
		}
		wp_send_json_success($response);
		wp_die();
	}


	public function new_user_register()
	{
		global $criteria;
		global $datum_user;

		$data 		= DM_Curl::HTTPPost($_POST, 'new-user-register');

		$request 	= json_decode($data);
		
		if ($request->status == 'success') {
			$data_new 		= DM_Curl::HTTPGet('acquisitioncriteria');
			$criteria 		= json_decode($data_new);
			$datum_user = $request->data;
			ob_start();
			include DM_ABSPATH . '/template/auth/user/registerprofile.php';
			$response = array(
				'type' 		=> 'success',
				'html'		=> ob_get_clean(),
				'email'		=> $_POST['email'],
				'password'	=> $_POST['password'],
				'user_id'	=> $request->user_id
			);
		} else {

			$response = array(
				'type' 	=> 'failure',
				'html'	=> $request->errors
			);
		}

		wp_send_json_success($response);
		wp_die();
	}

	public function user_register()
	{


		global $criteria;
		$data_new 		= DM_Curl::HTTPGet('acquisitioncriteria');
		$criteria 		= json_decode($data_new);
		if (!empty($_POST['markets'])) {
			$_POST['markets'] = implode(',', $_POST['markets']);
		}
		if (!empty($_POST['cell_phone'])) {
			$_POST['cell_phone'] = str_replace('-', '', $_POST['cell_phone']);
		}
		if (!empty($_POST['mobile_phone'])) {
			$_POST['mobile_phone'] = str_replace('-', '', $_POST['mobile_phone']);
		}

		if (isset($_POST['i_am'])) {
			if ($_POST['i_am'] == 1) {
				unset($_POST['brokertype_h']);
			}
			if ($_POST['i_am'] == 2) {
				unset($_POST['investor_type']);
			}
			if ($_POST['i_am'] == 3) {
				unset($_POST['brokertype_h']);
				unset($_POST['investor_type']);
			}
			if ($_POST['i_am'] == 4) {
				unset($_POST['brokertype_h']);
				unset($_POST['investor_type']);
			}
		}



		if (isset($_POST['DealSize']) && !empty($_POST['DealSize'])) {
			$_POST['DealSize'] = json_encode($_POST['DealSize']);
		}

		if (isset($_POST['SpacePropetyType']) && !empty($_POST['SpacePropetyType'])) {
			$_POST['SpacePropetyType'] = json_encode($_POST['SpacePropetyType']);
		}

		if (isset($_POST['Regions']) && !empty($_POST['Regions'])) {
			$_POST['Regions'] = json_encode($_POST['Regions']);
		}
		if (isset($_POST['State']) && !empty($_POST['State'])) {
			$_POST['State'] = json_encode($_POST['State']);
		}

		if (isset($_POST['PropetyType']) && !empty($_POST['PropetyType'])) {
			$_POST['PropetyType'] = json_encode($_POST['PropetyType']);
		}

		if (isset($_POST['PrefferedDealSize']) && !empty($_POST['PrefferedDealSize'])) {
			$_POST['PrefferedDealSize'] = json_encode($_POST['PrefferedDealSize']);
		}
		if (!empty($_POST['timing'])) {
			$_POST['timing'] = json_encode($_POST['timing']);
		}
		if (isset($_POST['PeferredMarketType']) && !empty($_POST['PeferredMarketType'])) {
			$_POST['PeferredMarketType'] = json_encode($_POST['PeferredMarketType']);
		}

		if (isset($_POST['InvestmentStraragy']) && !empty($_POST['InvestmentStraragy'])) {
			$_POST['InvestmentStraragy'] = json_encode($_POST['InvestmentStraragy']);
		}

		if (isset($_POST['ReturnMetrics']) && !empty($_POST['ReturnMetrics'])) {
			$_POST['ReturnMetrics'] = json_encode($_POST['ReturnMetrics']);
		}

		//}

		if (!empty($_POST['company_radio']) && $_POST['company_radio'] == 1) {
			$_POST['company']	= $_POST['company'];
		} else {
			$_POST['company']	= null;
		}
		if (!empty($_POST['state_select'])) {
			$_POST['state'] = $_POST['state_select'];
		} else if (!empty($_POST['state_text'])) {
			$_POST['state'] = $_POST['state_text'];
		} else {
			$_POST['state'] = '';
		}
		$step = $_POST['step'];


		if (isset($_FILES['avatar'])) {
			$_POST['avatar'] = $_FILES['avatar'];
		}
		$_POST['user_ip'] = $_SERVER['REMOTE_ADDR'];

		if (isset($_POST['profile_avatar']) && $_POST['profile_avatar'] != '') {
			if ($_POST['profile_avatar'] == 'https://datumdoc.blob.core.windows.net/datumfilecontainer/placeholders/agent-placeholder.png') {
				$_POST['profile_avatar'] = '';
			}
		}



		$data = DM_Curl::HTTPPost($_POST, 'user-register');
		

		$user = json_decode($data);


		$txt =  $data;
		$myfile = file_put_contents('logs.txt', $txt . PHP_EOL, FILE_APPEND | LOCK_EX);

		if ($user->status == 'success') {

			if ($step == 1) {
				global $datum_user;
				//$data = json_decode(DM_Curl::HTTPGet('check-plugin-key'));

				$datum_user = $user->data;


				ob_start();
				if ($_POST['i_am'] == '3' || $_POST['i_am'] == '2') {
					include DM_ABSPATH . '/template/auth/user/step/verify.php';
				} else {

					include DM_ABSPATH . '/template/auth/user/step/step-2.php';
				}

				//$html = ob_get_clean();

				$response = array(
					'type' 	=> 'success',
					'i_am'	=> $_POST['i_am'],
					//'html'	=> $html,
				);
				$response['newhtml'] = ob_get_clean();

				// if($_POST['i_am'] == '2'){
				// 	ob_start();
				// 	$user_id = $user->data->Id;
				// 	include DM_ABSPATH . '/template/auth/user/step/otp-2.php';
				// 	$response['newhottml'] = ob_get_clean();
				// }

				$response['html'] = $user->message;
			} else if ($step == 2) {
				global $datum_user;
				$datum_user = $user->data;
				ob_start();
				$response = array(
					'type' 	=> 'success',
					'i_am'	=> $_POST['i_am'],
					//'html'	=> $html,
				);
				include DM_ABSPATH . '/template/auth/user/step/verify.php';
				$response['newhtml'] = ob_get_clean();
				$response['html'] = $user->message;
			}
		} else {

			$response = errorcheck($user);
		}
		wp_send_json_success($response);
		wp_die();
	}

	public function download_ca_on_mylisting()
	{
		$_POST['user_ip'] = $_SERVER['REMOTE_ADDR'];
		$data 		= DM_Curl::HTTPPost($_POST, 'download-existing-ca');

		$request 	= json_decode($data);
		if ($request->status == 'success') {

			$upload_dir   	= wp_upload_dir();
			$name 			= $request->FileName;

			if (!file_exists($upload_dir['basedir'] . '/datum')) {
				mkdir($upload_dir['basedir'] . '/datum', 0777, true);
			}

			if (!file_exists($upload_dir['basedir'] . '/datum/ca')) {
				mkdir($upload_dir['basedir'] . '/datum/ca', 0777, true);
			}
			chmod($upload_dir['basedir'] . '/datum/ca/', 0777);

			$url 		= $request->URL;

			$file_path 	= $upload_dir['basedir'] . '/datum/ca/' . $name;

			file_put_contents($file_path, file_get_contents($url));
			chmod($file_path, 0777);

			$name = str_replace('_', ' ', $name);

			rename($file_path, $upload_dir['basedir'] . '/datum/ca/' . $name);

			$file_URL = $upload_dir['baseurl'] . '/datum/ca/' . $name;
			$response = array(
				'type' 	=> 'success',
				'html' 	=> '',
				'url' => $file_URL,
				'FileName' => $name,
			);
		} else {
			$response = array(
				'type' 	=> 'failed',
				'html' 	=> '',
				'FileName' => $request->FileName,
			);
		}
		wp_send_json_success($response);
		wp_die();
	}

	public function lastNameFields($lastName = "")
	{
		$lName = "";
		if ($lastName != "") {
			$op = substr($lastName, 0, 2);
			if ($op == "mc" || $op == "Mc" || $op == "MC") {
				$lastName1 = ucwords("Mc" . strtoupper(substr($lastName, 2, 1)) . strtolower(substr($lastName, 3)));
				$lName = $lastName1;
			} else {
				$lastName1 = ucwords(strtolower($lastName));
				$lName = $lastName1;
			}
		}
		return $lName;
	}

	public function removeSuiteInSuiteFields($suite = "")
	{
		$suiteString = "";
		if ($suite != "") {
			$suiteString  = str_ireplace('SUITE', "", $suite);
		}
		return $suiteString;
	}

	public function userAccessRequest()
	{
		if (isset($_POST['is_request'])) {
			$data 		= DM_Curl::HTTPPost(array('is_request' => 1), 'user-page-access');
			$userAccess = json_decode($data);
			$response = array(
				'type' 		=> 'success',
				'status'	=> $userAccess->type

			);
			wp_send_json_success($response);
			wp_die();
		}
	}
	public function insightAccessRequest()
	{
		if (isset($_POST['is_request'])) {
			$data 		= DM_Curl::HTTPPost(array('is_request' => 1), 'insight-page-access');
			$userAccess = json_decode($data);
			$response = array(
				'type' 		=> 'success',
				'status'	=> $userAccess->type

			);
			wp_send_json_success($response);
			wp_die();
		}
	}
	public function latest_insight($cat)
	{
		$data 		= DM_Curl::HTTPPost($_POST, 'insight-listing');

		$request 	= json_decode($data);
		if ($request->status == 'success') {
			ob_start();
			if (!empty($request->data->data)) {
				if ($_POST['Category'] == 'latestInsight') {
					global $datum_insight;
					$datum_insight = $request->data;
					include DM_ABSPATH . '/template/insights/latest_insights.php';
				} else {
					global $datum_insight;
					$datum_insight = $request->data;
					include DM_ABSPATH . '/template/insights/insights.php';
				}
				$response = array(
					'type' 		=> 'success',
					'html'		=> ob_get_clean(),
				);
			} else {
				include DM_ABSPATH . '/template/loop/no-products-found.php';
				$response = array(
					'type' 		=> 'success',
					'html'		=> ob_get_clean(),
				);
			}
		} else {
			$response = array(
				'type' 	=> 'failure',
				'html'	=> $request,
			);
		}
		wp_send_json_success($response);
		wp_die();
	}

	public function insight_view()
	{
		global $datum_user;
		$device = 0;
		if (wp_is_mobile()) {
			$device = 1;
		}
		$userDatas = '';
		$data = DM_Curl::HTTPPost(array('insight_id' => $_POST['hashId']), 'insight-page');
		$insight = json_decode($data);

		if (isset($_POST['Token']) && $_POST['Token'] != '') {

			$data = DM_Curl::HTTPPost(array('Token' => $_POST['Token']), 'check-insights-page');

			$insightUser = json_decode($data);
			$insightUserData = $insightUser->data;
			$cookie_value = '';
			if ($insightUser->status == 'success') {
				switch ($insightUser->type) {
					case 'needToUserlogin':
						$data = DM_Curl::HTTPPost(array('Id' => $insightUserData->UserId), 'user-login-id');
						$userData = json_decode($data);

						$cookie_name 	= "access_token";
						$cookie_value 	= $userData->access_token;
						setcookie($cookie_name, $cookie_value, time() + 86400, "/");
						$datum_user = $userData->data->user;
						$user_ID = $datum_user->Id;
						break;
					case 'NoAnyLogin':

						break;
					case 'same':
						break;
					default:
						break;
				}
			}
			$Iarray = array(
				'ip' 					=> $_SERVER['REMOTE_ADDR'],
				'device' 				=> $device,
				'insightId'				=> $insight->data->Id,
				'configurationsId'		=> $insightUserData->ConfigurationId,
				'HostedConfigurationId'	=> $insight->data->ConfigurationId,
				'nonhost'				=> true,
				'user_id'				=> $insightUserData->UserId,
			);


			$data = DM_Curl::HTTPPost($Iarray, 'insights-page-view', true, $cookie_value);
			$data = json_decode($data);
			$rep = true;
		} else {
			$Iarray = array(
				'ip' 					=> $_SERVER['REMOTE_ADDR'],
				'device' 				=> $device,
				'insightId'				=> $insight->data->Id,
				'configurationsId'		=> $insight->data->ConfigurationId,
				'HostedConfigurationId'	=> $insight->data->ConfigurationId,
				'nonhost'				=> $_POST['nonhost'],
				'user_id'				=> true
			);

			$data = DM_Curl::HTTPPost($Iarray, 'insights-page-view');
			$data = json_decode($data);
			$rep = false;
		}


		if ($data->status == 'success') {
			$response = array(
				'type' 		=> 'success',
				'html'		=> '',
				'data'		=> $datum_user,
				'rep'		=> $rep
			);
		} else {

			$response = array(
				'type' 	=> 'failure',
				'html'	=> $data,
			);
		}

		wp_send_json_success($response);
		wp_die();
	}

	public function insight_doc_tracking()
	{
		$data 		= DM_Curl::HTTPPost($_POST, 'insight-doc-tracking');
		$request 	= json_decode($data);

		$upload_dir   	= wp_upload_dir();
		$name 			= $request->data->Filename;

		if (!file_exists($upload_dir['basedir'] . '/datum')) {
			mkdir($upload_dir['basedir'] . '/datum', 0777, true);
		}
		if (!file_exists($upload_dir['basedir'] . '/datum/Insight')) {
			mkdir($upload_dir['basedir'] . '/datum/Insight', 0777, true);
		}

		chmod($upload_dir['basedir'] . '/datum/Insight/', 0777);

		$url 		= $request->data->FilePath;
		$file_path 	= $upload_dir['basedir'] . '/datum/Insight/' . $request->data->Filename;
		$flpath = $upload_dir['basedir'] . '/datum/Insight/';

		exec('wget  -P "' . $flpath . '" "' . $url . '"');
		chmod($file_path, 0777);

		$name = str_replace('_', ' ', $name);
		rename($file_path, $upload_dir['basedir'] . '/datum/Insight/' . $name);
		$file_URL = $upload_dir['baseurl'] . '/datum/Insight/' . $name;

		if ($request->status == 'success') {

			$response = array(
				'type' 		=> 'success',
				'url' 		=> $file_URL,
				'basename' 	=> $name,

			);
		} else {
			$response = array(
				'type' 	=> 'failure',
			);
		}

		wp_send_json_success($response);
		wp_die();
	}

	public function related_insights()
	{

		$data = DM_Curl::HTTPPost($_POST, 'related_insights');
		$request 	= json_decode($data);
		if ($request->status == 'success') {
			ob_start();
			global $single_insight;
			$single_insight = $request->data;

			include DM_ABSPATH . '/template/insights/pageparts/related_insights.php';

			$response = array(
				'type' 		=> 'success',
				'html'		=> ob_get_clean(),
			);
		} else {

			$response = array(
				'type' 	=> 'failure',
				'html'	=> $request,
			);
		}

		wp_send_json_success($response);
		wp_die();
	}

	public function NonHostedInsight()
	{
		$_POST['ip'] = $_SERVER['REMOTE_ADDR'];
		$data = DM_Curl::HTTPPost($_POST, 'nonhosted-insights');
		/* echo "<pre>";
		print_r($data);
		die; */
		$request 	= json_decode($data);
		if ($request->status == 'success') {
			$response = array(
				'type' 		=> 'success',
				'URL'		=> $request->URL,
			);
		} else {

			$response = array(
				'type' 	=> 'failure',
				'html'	=> $request,
			);
		}

		wp_send_json_success($response);
		wp_die();
	}

	// Checking Mobile Number And Phone Number
	public function checkMobileNumber()
	{
		$response = false;

		$cell_phone = str_replace('_', '', $_POST['cell_phone']);

		$cell_phone = str_replace('-', '', $cell_phone);

		if ($cell_phone != '' && strlen($cell_phone) >= 10) {
			$data = DM_Curl::HTTPPost($_POST, 'check-mobile-valid');
			$request 	= json_decode($data);
			if ($request->status == 'success') {
				$response = true;
			} else {

				$response = false;
			}
		}
		$response = true;
		echo json_encode($response);
		die;
	}

	public function get_region_by_state()
	{
		$_POST['ip'] = $_SERVER['REMOTE_ADDR'];

		$data = DM_Curl::HTTPPost($_POST, 'get-state-by-region');
		$request 	= json_decode($data);

		global $datum_user;
		$data = json_decode(DM_Curl::HTTPGet('check-plugin-key'));
		$datum_user = $data->user_data;

		if ($request->status == 'success') {
			ob_start();
			global $statesData, $contActacquisition;
			$statesData         = $request->data;
			$contActacquisition = $request->acquisition;

			include DM_ABSPATH . '/template/auth/user/step/StateData.php';
			$response = array(
				'type' 		=> 'success',
				'html'		=> ob_get_clean(),
			);
		} else {
			$response = array(
				'type' 	=> 'failure',
				'html'	=> $request,
			);
		}
		wp_send_json_success($response);
		wp_die();
	}

	public function agreementuser()
	{

		global $datum_user;
		$data = json_decode(DM_Curl::HTTPGet('check-plugin-key'));
		$datum_user = $data->user_data;

		if ($datum_user->IsLicenseAgreementAccepted == 1) {
			if ($_POST['LookupKey'] == 3) {


				$data = DM_Curl::HTTPPost($_POST, 'inquiry-email');
				$user = json_decode($data);
				$url = home_url('?advancedsubscription=1');
				$response = array(
					'type' 	=> 'success',
					'url'	=> $url,
					'redirect' => 1,

				);
			} else {
				$data = DM_Curl::HTTPPostDashborad($_POST, 'ChildSiteCheckout');
				$user = json_decode($data);

				$url = $user->url;
				$response = array(
					'type' 	=> 'success',
					'url'	=> $url
				);
			}
		} else {
			ob_start();
			$serverTime = new DateTime("now", new DateTimeZone(date_default_timezone_get()));
			$calcuttaTime = $serverTime->setTimezone(new DateTimeZone($_POST['timeZone']));

			$_POST['time'] =  $calcuttaTime->format('Y-m-d H:i:s');

			$_POST['user_ip'] = $_SERVER['REMOTE_ADDR'];
			$data = DM_Curl::HTTPPost($_POST, 'user-agreement');
			$agreementData = json_decode($data);
			include DM_ABSPATH . '/template/auth/user/step/agreementuser.php';
			$response = array(
				'type' 		=> 'success',
				'html'		=> ob_get_clean(),
				'url'		=> 0,
			);
		}


		wp_send_json_success($response);
		wp_die();
	}

	public function verifyEmail()
	{
		$_POST['user_ip'] 	= $_SERVER['REMOTE_ADDR'];

		$_POST['otp'] 	= $_POST['opt'];

		$data = DM_Curl::HTTPPost($_POST, 'verify-email-otp');

		$user = json_decode($data);

		if ($user->status == 'success') {
			$response = array(
				'type' 	=> 'success',
			);
		} else {
			$response = array(
				'type' 	=> 'failure',
				'html'	=> $user->message
			);
		}
		wp_send_json_success($response);
		wp_die();
	}

	public function checkoutUser()
	{
		if ($_POST['LookupKey'] == 3) {

			$data = DM_Curl::HTTPPostDashborad($_POST, 'ChildSiteLicenseAgreement');
			$user = json_decode($data);

			$data = DM_Curl::HTTPPost($_POST, 'inquiry-email');
			$user = json_decode($data);
			$url = home_url('?advancedsubscription=1');
			$response = array(
				'type' 	=> 'success',
				'url'	=> $url,
				'redirect' => 1,

			);
		} else {

			$data = DM_Curl::HTTPPostDashborad($_POST, 'ChildSiteLicenseAgreement');

			$user = json_decode($data);

			$data = DM_Curl::HTTPPostDashborad($_POST, 'ChildSiteCheckout');

			$user = json_decode($data);

			$url = $user->url;

			$response = array(
				'type' 	=> 'success',
				'url'	=> $url,
				'redirect' => 0,
			);
		}

		wp_send_json_success($response);
		wp_die();
	}

	public function LoginOtp()
	{
		global $datum_user;
		if (!empty($_POST['mobile_phone'])) {
			$_POST['mobile_phone'] = str_replace('-', '', $_POST['mobile_phone']);
		}

		$account = 0;
		$verify_acc = 2;

		if (isset($_POST['otp']) && trim($_POST['otp']) != '') {


			$_POST['otp'] = str_replace('-', '', $_POST['otp']);
			$_POST['user_ip'] = $_SERVER['REMOTE_ADDR'];

			$data = DM_Curl::HTTPPost($_POST, 'verify-mobile-otp');

			$request = json_decode($data);

			$datum_user = $request->data;
			$cookie_name 	= "access_token";
			$cookie_value 	= $request->access_token;


			setcookie($cookie_name, $cookie_value, time() + 86400, "/");

			$verify_acc = 1;

			if ($request->status == 'success') {
				$response = array(
					'type' 	=> 'success',
					//'html'	=> $request->message,
					'account'	=> $account,
					'caType'	=> $_POST['caType'],
					'property_id'	=> $_POST['property_id'],
					'press_release'	=> $_POST['press_release'],
					'favorite'	=> $_POST['favorite'],
					'favProperty'	=> $_POST['favProperty'],
					//'account_verify' = true,
				);

				ob_start();
				include DM_ABSPATH . '/template/auth/user/step/otp_success.php';
				$response['html'] = ob_get_clean();
			} else {
				if (empty($request->errors)) {
					$response = array(
						'type' 	=> 'failure',
						'html'	=> $request->message,
						'array'	=> '0',
						'account'	=> $account,
						'isDesabled' => isset($request->isDesabled) ? $request->isDesabled : false
					);
				} else {
					$response = array(
						'type' 	=> 'failure',
						'html'	=> $request->errors,
						'array'	=> '1',
						'account'	=> $account,
						'isDesabled' => isset($request->isDesabled) ? $request->isDesabled : false
					);
				}
			}
		} else {

			$_POST['user_ip'] = $_SERVER['REMOTE_ADDR'];
			$data = DM_Curl::HTTPPost($_POST, 'resend-mobile-otp');

			$request = json_decode($data);

			if (isset($request->account) && $request->account == 1) {
				$account = '1';
			}
			if ($request->status == 'success') {
				$response = array(
					'type' 	=> 'success',
					'html'	=> $request->message,
					'verify' => 2,
					'account'	=> $account
				);
			} else {
				if (empty($request->errors)) {
					$response = array(
						'type' 	=> 'failure',
						'html'	=> $request->message,
						'array'	=> '0',
						'account'	=> $account
					);
				} else {

					if (isset($request->name) && $request->name != '') {
						$errors = array('mobile_phone' => $request->errors[0]);
					} else {
						$errors = $request->errors;
					}

					$response = array(
						'type' 	=> 'failure',
						'html'	=> $errors,
						'array'	=> '1',
						'account'	=> $account
					);
				}
			}
		}
		$response['verify_acc'] = $verify_acc;
		wp_send_json_success($response);
		wp_die();
	}

	public function OMDD()
	{

		global $datum_user;
		$device = 0;
		if (wp_is_mobile()) {
			$device = 1;
		}
		$data = DM_Curl::HTTPGet('user', array(), $_COOKIE['access_token']);
		$datum_user = json_decode($data);

		if (isset($_POST['caType']) && $_POST['caType'] != '') {
			$filesNotFound = 1;

			$postData = array(
				'caType'	=> $_POST['caType'],
				'documentType'	=> $_POST['caType'],
				'propertyId'	=> $_POST['property_id'],
				'device'	=> $device,
				'user_ip' =>  $_SERVER['REMOTE_ADDR'],
				'page_view_count' => 1,

			);
			global $single_property, $datum_user;
			$property_id = $_POST['property_id'];
			$id = "get-property/" . $property_id . "/0";
			$data = DM_Curl::HTTPGet($id, array(), $_COOKIE['access_token']);
			$property = json_decode($data);
			$single_property = $property->data;


			$data = DM_Curl::HTTPGet('user', array(), $_COOKIE['access_token']);
			$datum_user = json_decode($data);


			$checkCaSign = DM_Curl::HTTPPost($postData, 'property-docoument-list', true, $_COOKIE['access_token']);

			$agreementData = json_decode($checkCaSign);

			if ($agreementData->status == 'failed') {
				include DM_ABSPATH . '/template/auth/no-popuphtml.php';
			} else {
				switch ($agreementData->type) {
					case 'agreement':
						include DM_ABSPATH . '/template/auth/agreement.php';
						break;
					case 'Approved':
						$html = $agreementData->html;
						$type = $_POST['caType'];
						include DM_ABSPATH . '/template/auth/document_vault_structure.php';
						break;
					case 'agreement_success':
						$show = true;
						include DM_ABSPATH . '/template/auth/agreement.php';
						break;
					case 'Rejected':
						include DM_ABSPATH . '/template/auth/om-reject-message.php';
						break;
					case 'OmRequested':
						include DM_ABSPATH . '/template/auth/OmRequested.php';
						break;
					case 'ddrequested':
						include DM_ABSPATH . '/template/auth/ddalreadysended.php';
						break;
					case 'Pending':
					case 'Requested':
					case 'om-message-popup':
						include DM_ABSPATH . '/template/auth/om-message-popup.php';
						break;
					case 'agent-not-found':
						include DM_ABSPATH . '/template/auth/agent-not-found.php';
						break;
					case 'agent-not-found':
						include DM_ABSPATH . '/template/auth/agent-not-found.php';
						break;
					case 'OmRequestednotsedndd':
						include DM_ABSPATH . '/template/auth/omalreadysended.php';
						break;
					case 'DD':
						if ($agreementData->status == "success") {
							if (!empty($agreementData->data)) {
								if ($agreementData->data->DuediligenceRequestStatus == 2) {
									include DM_ABSPATH . '/template/auth/dd_success.php';
								} elseif ($agreementData->data->DuediligenceRequestStatus == 3) {
									$high_security = false;

									if (isset($agreementData->high_security) && $agreementData->high_security) {
										$high_security = true;
									}
									if (isset($agreementData->dddocflag)) {
										$dddocflag = $agreementData->dddocflag;
									} else {
										$dddocflag = false;
									}
									$type = $_POST['caType'];
									$html = $agreementData->html;
									include DM_ABSPATH . '/template/auth/document_vault_structure.php';
								} elseif ($agreementData->data->DuediligenceRequestStatus == 4) {
									include DM_ABSPATH . '/template/auth/dd_rejected.php';
								} else {
									include DM_ABSPATH . '/template/auth/due_diligence.php';
								}
							} else {
								include DM_ABSPATH . '/template/auth/due_diligence.php';
							}
						} else {
							include DM_ABSPATH . '/template/auth/no-popuphtml.php';
						}
						break;
					default:
						include DM_ABSPATH . '/template/auth/no-popuphtml.php';
						// code...
						break;
				}
			}

			$response = array(
				'type' 	=> 'success',
				'html'	=> ob_get_clean(),
				'dd_html'	=> $html,
			);
			wp_send_json_success($response);
			wp_die();
		}


		if (isset($_POST['press_release']) && $_POST['press_release'] == 'press_release') {

			$data = array(
				'press_release'	=> $_POST['press_release'],
				'property_id'	=> $_POST['property_id'],
				'user_id'		=> $datum_user->Id,
			);

			$data_view  = DM_Curl::HTTPPost($data, 'press-release', true, $_COOKIE['access_token'], array());
			$press = json_decode($data_view);


			$property_id = $_POST['property_id'];


			$pageViewData = array(
				'id' => $property_id,
				'ip' => $_SERVER['REMOTE_ADDR'],
				'device' => $device
			);
			$data_view  = DM_Curl::HTTPPost($pageViewData, 'page-view', true, $_COOKIE['access_token'], array());



			if ($press->data->IsPressReleaseFile == 1) {

				$upload_dir   	= wp_upload_dir();
				$name 			= $user->press_release->FileName;
				if (!file_exists($upload_dir['basedir'] . '/datum')) {
					mkdir($upload_dir['basedir'] . '/datum', 0777, true);
				}
				if (!file_exists($upload_dir['basedir'] . '/datum/press_release')) {
					mkdir($upload_dir['basedir'] . '/datum/press_release', 0777, true);
				}

				chmod($upload_dir['basedir'] . '/datum/press_release/', 0777);

				$url 		= $user->press_release->PressReleaseFile;
				$file_path 	= $upload_dir['basedir'] . '/datum/press_release/' . $name;
				$flpath = $upload_dir['basedir'] . '/datum/press_release/';

				exec('wget  -P "' . $flpath . '" "' . $url . '"');
				chmod($file_path, 0777);

				$name = str_replace('_', ' ', $name);
				rename($file_path, $upload_dir['basedir'] . '/datum/press_release/' . $name);
				$file_URL = $upload_dir['baseurl'] . '/datum/press_release/' . $name;

				$response = array(
					'type' 	=> 'success',
					'press_release_type'	=> 1,
					'is_press_release'	=> 1,
					'pp_link'	=> $file_URL,
					'pp_name'	=> $name,
				);
			} else {
				$response = array(
					'type' 	=> 'success',
					'press_release_type'	=> 1,
					'is_press_release'	=> 0,
					'pp_link'	=> $press->data->PressReleaseLink,
				);
			}

			wp_send_json_success($response);
			wp_die();
		}

		if (isset($_POST['favProperty']) && $_POST['favProperty'] == 'favProperty') {


			$favoriteArray = array(
				'user_id' => $datum_user->Id,
				'property_id' => $_POST['property_id'],
			);
			$favorite = DM_Curl::HTTPPost($favoriteArray, 'favorite', true, $_COOKIE['access_token']);
			$favorite = json_decode($favorite);
			if (isset($_POST['favProperty']) && $_POST['favProperty'] != '') {
				$favoriteFlag['property_id'] = $property_id;
			}
			$favoritesStatus = '';
			if ($favorite->status == 'success') {
				if ($favorite->data->favorite) {
					$favoriteFlag['favrite'] = true;
					$favoriteFlag['remove_favrite'] = false;
					$favoriteFlag['popup'] = false;
				} else {
					$favoriteFlag['favrite'] = false;
					$favoriteFlag['remove_favrite'] = true;
					$favoriteFlag['popup'] = false;
				}
			}
			$response = array(
				'type' 	=> 'success',
				//'html'	=> ob_get_clean(),
				//'IsAccountVerified'	=> 1,
				'favorite' => $favoriteFlag
			);
			wp_send_json_success($response);
			wp_die();
		}
	}

	public function membership_confrim_cancel()
	{
		global $datum_user;
		$data = json_decode(DM_Curl::HTTPGet('check-plugin-key'));
		$datum_user = $data->user_data;

		$data = DM_Curl::HTTPPostDashborad(array('UserId' => $datum_user->Id), 'ChildSiteCancelSubscription');
		$user = json_decode($data);


		if (!empty($_POST['first_name'])) {
			$_POST['first_name'] = ucwords(strtolower($_POST['first_name']));
		}

		if (!empty($_POST['last_name'])) {
			$_POST['last_name'] = DM_AJAX::lastNameFields(($_POST['last_name']));
		}

		if (!empty($_POST['suite'])) {
			$_POST['suite'] = DM_AJAX::removeSuiteInSuiteFields(($_POST['suite']));
		}

		if (!empty($_POST['street'])) {
			$_POST['street'] = ucwords(strtolower($_POST['street']));
		}

		if (!empty($_POST['city'])) {
			$_POST['city'] = ucwords(strtolower($_POST['city']));
		}

		if (!empty($_POST['email'])) {
			$_POST['email'] = strtolower($_POST['email']);
		}

		if (!empty($_POST['markets'])) {
			$_POST['markets'] = implode(',', $_POST['markets']);
		}
		if (!empty($_POST['cell_phone'])) {
			$_POST['cell_phone'] = str_replace('-', '', $_POST['cell_phone']);
		}
		if (!empty($_POST['mobile_phone'])) {
			$_POST['mobile_phone'] = str_replace('-', '', $_POST['mobile_phone']);
		}

		if (!empty($_POST['state_select'])) {
			if ($_POST['country'] == 'US') {
				$_POST['state'] = $_POST['state_select'];
			} else {
				$_POST['state'] = $_POST['state_text'];
			}
		} else if (!empty($_POST['state_text'])) {
			$_POST['state'] = $_POST['state_text'];
		} else {
			$_POST['state'] = '';
		}
		$step = $_POST['step'];

		if (!empty($_POST['company_radio']) && $_POST['company_radio'] == 1) {
			$_POST['company']	= $_POST['company'];
		} else {
			$_POST['company']	= null;
		}
		if (isset($_FILES['avatar'])) {
			$_POST['avatar'] = $_FILES['avatar'];
		}
		$f = substr($_POST['firstName'], 0, 1);
		$l = substr($_POST['lastName'], 0, 1);

		$_POST['user_ip'] = $_SERVER['REMOTE_ADDR'];
		if (isset($_POST['i_am'])) {
			if ($_POST['i_am'] == 1) {
				unset($_POST['brokertype_h']);
			}
			if ($_POST['i_am'] == 2) {
				unset($_POST['investor_type']);
			}
			if ($_POST['i_am'] == 3) {
				unset($_POST['brokertype_h']);
				unset($_POST['investor_type']);
			}
			if ($_POST['i_am'] == 4) {
				unset($_POST['brokertype_h']);
				unset($_POST['investor_type']);
			}
		}

		if (!empty($_POST['PropetyType'])) {
			$_POST['PropetyType'] = json_encode($_POST['PropetyType']);
		}

		if (!empty($_POST['PeferredMarketType'])) {
			$_POST['PeferredMarketType'] = json_encode($_POST['PeferredMarketType']);
		}

		if (!empty($_POST['InvestmentStraragy'])) {
			$_POST['InvestmentStraragy'] = json_encode($_POST['InvestmentStraragy']);
		}

		if (!empty($_POST['ReturnMetrics'])) {
			$_POST['ReturnMetrics'] = json_encode($_POST['ReturnMetrics']);
		}

		if (!empty($_POST['PrefferedDealSize'])) {
			$_POST['PrefferedDealSize'] = json_encode($_POST['PrefferedDealSize']);
		}

		if (!empty($_POST['timing'])) {
			$_POST['timing'] = json_encode($_POST['timing']);
		}



		if (!empty($_POST['Regions'])) {
			$_POST['Regions'] = json_encode($_POST['Regions']);
		}

		if (!empty($_POST['SpacePropetyType'])) {
			$_POST['SpacePropetyType'] = json_encode($_POST['SpacePropetyType']);
		}

		if (!empty($_POST['State'])) {
			$_POST['State'] = json_encode($_POST['State']);
		}





		//if ( $_POST['step'] == 2) {
		// print_r($_POST);
		// die;
		//}

		$data = DM_Curl::HTTPPost($_POST, 'profile');

		// die;
		$user = json_decode($data);



		$_POST['user_agent'] 	= $_SERVER['HTTP_USER_AGENT'];
		$_POST['user_ip'] 		= $_SERVER['REMOTE_ADDR'];

		$data 	= DM_Curl::HTTPPost($_POST, 'logout');
		$logout = json_decode($data);

		if ($logout->status == 'success') {

			unset($_COOKIE['access_token']);
			setcookie('access_token', null, -1, '/');
			unset($_SESSION['HYBRIDAUTH::STORAGE']);
			$response = array(
				'type' 	=> 'success',
			);
		} else {
			$response = array(
				'type' 	=> 'failure',
				'html'	=> $errors
			);
		}
		wp_send_json_success($response);
		wp_die();
	}

	public function dashbordLogin()
	{
		$_POST['RouteURL']	= 'subscriptions';

		$data = DM_Curl::HTTPPostDashborad($_POST, 'RedirectFromChildToParent');
		$user = json_decode($data);

		$response = array(
			'type' 	=> 'success',
			'URL'	=> $user->parentSiteUrl,
		);
		wp_send_json_success($response);
		wp_die();
	}

	public function resendmobileotp(){
		$_POST['user_ip'] = $_SERVER['REMOTE_ADDR'];

		$data = DM_Curl::HTTPPost($_POST, 'resend-mobile-otp');
		
		$request = json_decode($data);


	}
	public function resend_email_step(){
		 if (isset($_POST['user_id']) && !empty($_POST['user_id'])) {
	        $user_id = intval($_POST['user_id']);

	        // Prepare request payload
	        $request_data = array(
	            'user_id' => $user_id
	        );

	        // Call the external function or API
	        $data = DM_Curl::HTTPPost($request_data, 'resend-email-verification');
	        
	        $response_data = json_decode($data, true);

	        // Check if the response is valid
	        if (!empty($response_data) && isset($response_data['status']) && $response_data['status'] === 'success') {
	            $response = array(
	                'type' => 'success',
	                'message' => 'Verification email has been resent successfully.'
	            );
	        } else {
	            $response = array(
	                'type' => 'failure',
	                'message' => !empty($response_data['message']) ? $response_data['message'] : 'Failed to resend the verification email. Please try again later.'
	            );
	        }
	    } else {
	        $response = array(
	            'type' => 'failure',
	            'message' => 'Invalid request. User ID is missing or incorrect.'
	        );
	    }

		wp_send_json_success($response);
		wp_die();
	}
}
function fileUrl($url = "")
{
	$parts = parse_url($url);
	$path_parts = array_map('rawurldecode', explode('/', $parts['path']));
	return $parts['scheme'] . '://' . $parts['host'] . implode('/', array_map('rawurlencode', $path_parts));
}
new DM_AJAX();
