<?php
defined( 'ABSPATH' ) || exit;
/**
 * DM_Query Class.
 */
class DM_Curl {


    public function httpHader(){
        return array('activation_key:'.get_option('datum_api_key_id'),'site_url:'. home_url());
    }

    /**
     * Get any errors from querystring.
     */
    public function get_errors() {
        // phpcs:ignore WordPress.Security.NonceVerification.Recommended
        $error = ! empty( $_GET['dm_error'] ) ? sanitize_text_field( wp_unslash( $_GET['dm_error'] ) ) : '';

        if ( $error && ! dm_has_notice( $error, 'error' ) ) {
            dm_add_notice( $error, 'error' );
        }
    }
    /**
     * @description Make HTTP-GET call
     * @param       $url
     * @param       array $params
     * @return      HTTP-Response body or an empty string if the request fails or is empty
     */
    
    public static function HTTPGet($url ='',$params = [],$access_token = '') {
        $query = http_build_query($params);
        
        $httpHader = array('activation_key:'.get_option('datum_api_key_id'),'site_url:'. home_url());
        
        if(isset($_COOKIE['access_token']) && $_COOKIE['access_token'] != '') {
            array_push($httpHader,'Authorization:Bearer '. $_COOKIE['access_token']);
        }else if($access_token != '') {
            array_push($httpHader,'Authorization:Bearer '. $access_token);
        }
        array_push($httpHader,'Accept:application/json');
        $ch = curl_init(Datum_API_URL.$url.'?'.$query);
        curl_setopt($ch, CURLOPT_CUSTOMREQUEST , 'GET');
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($ch, CURLOPT_HTTPHEADER,$httpHader);
        $response = curl_exec($ch);
        curl_close($ch);
        return $response; 
    }
    
    /**
     * @description Make HTTP-POST call
     * @param       $url
     * @param       array $params
     * @return      HTTP-Response body or an empty string if the request fails or is empty
     */
    public static function HTTPPost($params = array(), $url = '', $http = true, $access_token = '',$file = array()) {


        if(isset($params['timezon']) && $params['timezon'] != "") {
            date_default_timezone_set($params['timezon']);
        }

        $httpHader = array('activation_key:'.get_option('datum_api_key_id'),'site_url:'. home_url(),'Accept:application/json', 'current_date_time:'.date('F d, Y h:i A'), 'current_time:'.date('h:i A'), 'current_date:'.date('F d, Y'));

        if(isset($_COOKIE['access_token']) && $_COOKIE['access_token'] != '' && $access_token == '') {
            array_push($httpHader,'Authorization:Bearer '. $_COOKIE['access_token']);
        }else if($access_token != '') {
            array_push($httpHader,'Authorization:Bearer '. $access_token);
        }
        array_push($httpHader,'Accept:application/json');
        //$_FILES['avatar'] = array();
        $params['user_ip']      = $_SERVER['REMOTE_ADDR'];
        $params['user_agent']   = $_SERVER['HTTP_USER_AGENT'];
    
        if(isset($_FILES['avatar']) && $_FILES['avatar']['name'] != ''){
            if (function_exists('curl_file_create')) {
                $cFile = new CurlFile($_FILES['avatar']['tmp_name'], $_FILES['avatar']['type'], $_FILES['avatar']['name']);
                //$cFile = curl_file_create($data['ad_paths']);
            } else {
                $cFile = '@' . realpath($_FILES['file']['tmp_name']);
            }
            $params['avatar'] = $cFile;
            $query = $params;
        }else{
            
            $query = http_build_query($params);
            //$query = $params;
        }

        $ch    = curl_init();
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);

        if($http){
            curl_setopt($ch, CURLOPT_HTTPHEADER, $httpHader);
        }
        
        curl_setopt($ch, CURLOPT_URL, Datum_API_URL . $url);
        curl_setopt($ch, CURLOPT_POST, true);
        curl_setopt($ch, CURLOPT_MAXREDIRS, 10);
        curl_setopt($ch, CURLOPT_TIMEOUT, 0);
        curl_setopt($ch, CURLOPT_ENCODING, true);
        curl_setopt($ch, CURLOPT_FOLLOWLOCATION, true);
        curl_setopt($ch, CURLOPT_POSTFIELDS, $query);
        $response = curl_exec($ch);
        /*pr($response);
        die;*/
        curl_close($ch);
        
        return $response;
    }

    /**
     * @description Make HTTP-POST call
     * @param       $url
     * @param       array $params
     * @return      HTTP-Response body or an empty string if the request fails or is empty
     */
    public static function HTTPPostDashborad($params = array(), $url = '') {
     try {
            $httpHeader = [];
            array_push($httpHeader, 'Accept: application/json');
            //$_FILES['avatar'] = array();
            $params['IpAddress'] = $_SERVER['REMOTE_ADDR'];
            $params['ChildSiteUrl'] = home_url();
            $params['Timezone'] = 'Asia/Calcutta';
            
            $curl = curl_init();
            curl_setopt_array($curl, array(
                CURLOPT_URL => 'https://api.datatodeals.com/Api/'.$url,
                CURLOPT_RETURNTRANSFER => true,
                //CURLOPT_ENCODING => '',
                //CURLOPT_MAXREDIRS => 10,
                //CURLOPT_TIMEOUT => 0,
                CURLOPT_FOLLOWLOCATION => true,
                CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
                CURLOPT_CUSTOMREQUEST => 'POST',
                CURLOPT_POSTFIELDS => json_encode($params),
                CURLOPT_HTTPHEADER => array(
                    'Content-Type: application/json',
                    'Origin:'.home_url()
                ),
            ));

            $response = curl_exec($curl);
           
            if(curl_errno($curl)) {
                throw new Exception('cURL error: ' . curl_error($curl));
            }

            curl_close($curl);

            return $response;

        } catch (Exception $e) {
            // Handle the error
            return json_encode(['error' => $e->getMessage()]);
        }

    }
    /**
     * @description Make HTTP-PUT call
     * @param       $url
     * @param       array $params
     * @return      HTTP-Response body or an empty string if the request fails or is empty
     */
    public static function HTTPPut(array $params) {
        $query = \http_build_query($params);
        $ch    = \curl_init();
        \curl_setopt($ch, \CURLOPT_RETURNTRANSFER, true);
        \curl_setopt($ch, \CURLOPT_HEADER, false);
        \curl_setopt($ch, \CURLOPT_URL, Datum_API_URL);
        \curl_setopt($ch, \CURLOPT_CUSTOMREQUEST, 'PUT');
        \curl_setopt($ch, \CURLOPT_POSTFIELDS, $query);
        $response = \curl_exec($ch);
        \curl_close($ch);
        return $response;
    }
    /**
     * @category Make HTTP-DELETE call
     * @param    $url
     * @param    array $params
     * @return   HTTP-Response body or an empty string if the request fails or is empty
     */
    public static function HTTPDelete(array $params) {
        $query = \http_build_query($params);
        $ch    = \curl_init();
        \curl_setopt($ch, \CURLOPT_RETURNTRANSFER, true);
        \curl_setopt($ch, \CURLOPT_HEADER, false);
        \curl_setopt($ch, \CURLOPT_URL, Datum_API_URL);
        \curl_setopt($ch, \CURLOPT_CUSTOMREQUEST, 'DELETE');
        \curl_setopt($ch, \CURLOPT_POSTFIELDS, $query);
        $response = \curl_exec($ch);
        \curl_close($ch);
        return $response;
    }

    /**
     * @description Make HTTP-POST call
     * @param       $url
     * @param       array $params
     * @return      HTTP-Response body or an empty string if the request fails or is empty
     */
    public static function HTTPPostAzureFunction( $fileArray = "" ) {
        $url = ZIP_URL;
        $ch = curl_init($url);
        $data = array(
            'username' => 'codexworld',
            'password' => '123456'
        );
        curl_setopt($ch, CURLOPT_POSTFIELDS, $fileArray);
        curl_setopt($ch, CURLOPT_HTTPHEADER, array(
                "cache-control: no-cache",
                "content-type: application/json",
                "postman-token: c20ee635-e68c-3db7-807a-b2d9e8023154"
            ));
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
        $result = curl_exec($ch);
        curl_close($ch);
        return $result;
    }
}   