<?php

/**
 * Handle frontend scripts
 *
 * @package datum/Classes
 * @version 2.3.0
 */

use ScssPhp\ScssPhp\Compiler;
use ScssPhp\ScssPhp\ValueConverter;


if (! defined('ABSPATH')) {
	exit;
}

/**
 * Frontend scripts class.
 */
class DM_Frontend_Scripts
{

	/**
	 * Contains an array of script handles registered by DM.
	 *
	 * @var array
	 */
	private static $scripts = array();

	/**
	 * Contains an array of script handles registered by DM.
	 *
	 * @var array
	 */
	private static $styles = array();

	/**
	 * Contains an array of script handles localized by DM.
	 *
	 * @var array
	 */
	private static $wp_localize_scripts = array();

	/**
	 * Hook in methods.
	 */
	public static function init()
	{
		add_action('wp_enqueue_scripts', array(__CLASS__, 'load_scripts'), 9999);
		//add_action( 'get_footer', array(__CLASS__, 'prefix_add_footer_styles'));
		//$this->prefix_add_footer_styles();
	}

	/**
	 * Register all DM scripts.
	 */
	private static function register_scripts()
	{
		global $post;
		$register_scripts = array(
			'jquery-2.2.0.min' => array(
				'src'     	=> self::get_asset_url('js/jquery-2.2.0.min.js'),
				'deps'    	=> array('jquery'),
				'version' 	=> '2.7.2',
				'pageAccess' => array(),
			),
			'isotope.min' => array(
				'src'     => self::get_asset_url('js/isotope.pkgd.min.js'),
				'deps'    => array('jquery'),
				'version' => '2.7.2',
				'pageAccess' => array(),
			),
			'validate.min' => array(
				'src'     => self::get_asset_url('js/jquery.validate.min.js'),
				'deps'    => array('jquery'),
				'version' => '2.7.2',
				'pageAccess' => array(),
			),
			'googleapis.min' => array(
				//'src'     => 'https://maps.googleapis.com/maps/api/js?v=3&sensor=false&amp;libraries=drawing&key=AIzaSyAz1i7NKNid233vroT84pDx5C2euq0Q34s',
				'src'     => 'https://maps.googleapis.com/maps/api/js?v=3&sensor=false&amp;libraries=drawing&key=AIzaSyA1rFEL8kNE80CeM8fiN38qctiSqNu5mE8',
				'deps'    => array('jquery'),
				'version' => '2.7.2',
				'pageAccess' => array('datum_property_listing_id', 'datum_property_closed_id'),
			),
			'markerclusterer_compiled' => array(
				'src'     	=> 'https://cdnjs.cloudflare.com/ajax/libs/js-marker-clusterer/1.0.0/markerclusterer_compiled.js',
				'deps'    	=> array('jquery'),
				'version' 	=> '2.7.2',
				'pageAccess' => array('datum_property_listing_id', 'datum_property_closed_id'),
			),
			'select2.min' 	=> array(
				'src'     	=> self::get_asset_url('js/select2.min.js'),
				'deps'    	=> array('jquery'),
				'version' 	=> '2.7.2',
				'pageAccess' => array(),
			),
			'slick' => array(
				'src'     	=> self::get_asset_url('js/slick.min.js'),
				'deps'   	=> array('jquery'),
				'version' 	=> '2.7.2',
				'pageAccess' => array(),
			),
			'lightgallery' => array(
				'src'     => self::get_asset_url('js/lightgallery-all.min.js'),
				'deps'    => array('jquery'),
				'version' => '2.7.2',
				'pageAccess' => array(),
			),
			'jquery.lazy.min.js' => array(
				'src'     => self::get_asset_url('js/jquery.lazy.min.js'),
				'deps'    => array('jquery'),
				'version' => '2.7.2',
				'pageAccess' => array(),
			),
			'cropper.js' => array(
				'src'     => self::get_asset_url('js/cropper.min.js'),
				'deps'    => array('jquery'),
				'version' => '2.7.2',
				'pageAccess' => array(),
			),
			'map.js' => array(
				'src'     => self::get_asset_url('js/map.min.js'),
				'deps'    => array('jquery'),
				'version' => '2.7.2',
				'pageAccess' => array('datum_property_listing_id', 'datum_property_closed_id'),
			),
			'auth.js' => array(
				'src'     => self::get_asset_url('js/auth.min.js'),
				'deps'    => array('jquery'),
				'version' => '2.7.2',
				'pageAccess' => array(),
			),
			'custom' => array(
				'src'     => self::get_asset_url('js/custom.min.js'),
				'deps'    => array('jquery'),
				'version' => time(),
				'pageAccess' => array(),
			),
			'main' => array(
				'src'     => self::get_asset_url('js/main.min.js'),
				'deps'    => array('jquery'),
				'version' => time(),
				'pageAccess' => array(),
			),
			'property-single' => array(
				'src'     => self::get_asset_url('js/property-single.min.js'),
				'deps'    => array('jquery'),
				'version' => time(),
				'pageAccess' => array('datum_property_listing_id', 'datum_property_closed_id'),
			),
			'property_filter.js' => array(
				'src'     => self::get_asset_url('js/property_filter.js'),
				'deps'    => array('jquery'),
				'version' => time(),
				'pageAccess' => array('datum_property_listing_id', 'datum_property_closed_id'),
			),
			'profile_image.js' => array(
				'src'     => self::get_asset_url('js/profile_image.min.js'),
				'deps'    => array('jquery'),
				'version' => '2.7.2',
				'pageAccess' => array(),
			),
			'profile-cropper.js' => array(
				'src'     => self::get_asset_url('js/profile-cropper.min.js'),
				'deps'    => array('jquery'),
				'version' => '2.7.2',
				'pageAccess' => array(),
			),
			'insight' => array(
				'src'     => self::get_asset_url('js/insights.min.js'),
				'deps'    => array('jquery'),
				'version' => '2.7.2',
				'pageAccess' => array('datum_insights_page_id'),
			),
			/**
			 * Tag editor for search textbox
			 */
			'jquery-ui.min' => array(
				'src'     => self::get_asset_url('js/jquery-ui.min.js'),
				'deps'    => array('jquery'),
				'version' => '2.7.2',
				'pageAccess' => array(),
			),
			'jquery.tagsinput-revisited' => array(
				'src'     	=> self::get_asset_url('js/jquery.tagsinput-revisited.js'),
				'deps'    	=> array('jquery'),
				'version' 	=> '2.7.2',
				'pageAccess' => array(),
			),
			'jquery.inputmask.bundle.js' => array(
				'src'     => self::get_asset_url('js/jquery.inputmask.bundle.min.js'),
				'deps'    => array('jquery'),
				'version' => '2.7.2',
				'pageAccess' => array(),
			),
			'inputmask.dependencyLib' => array(
				'src'     => self::get_asset_url('js/inputmask.dependencyLib.min.js'),
				'deps'    => array('jquery'),
				'version' => '2.7.2',
				'pageAccess' => array(),
			),
			'inputmask' => array(
				'src'     	=> self::get_asset_url('js/inputmask.min.js'),
				'deps'    	=> array('jquery'),
				'version' 	=> '2.7.2',
				'pageAccess' => array(),
			),
			'inputmask.date.extension' => array(
				'src'     	=> self::get_asset_url('js/inputmask.date.extensions.js'),
				'deps'    	=> array('jquery'),
				'version' 	=> '2.7.2',
				'pageAccess' => array(),
			),
			'pannellum-script' => array(
				'src'     => "https://cdn.jsdelivr.net/npm/pannellum@2.5.6/build/pannellum.js",
				'deps'    => array('jquery'),
				'version' => time(),
				'pageAccess' => array('datum_for_lease_listing_id'),
			),
			'for-lease-page' => array(
				'src'     => self::get_asset_url('js/for_lease_page.js'),
				'deps'    => array('jquery'),
				'version' => time(),
				'pageAccess' => array('datum_for_lease_listing_id'),
			),
		);
		$post_name = get_option('datum_property_listing_id');
		$post_type = get_option('datum_property_type_id');
		global $post, $property, $single_property;
		foreach ($register_scripts as $name => $props) {
			if (!empty($props['pageAccess'])) {
				if (!is_front_page() && !is_home()) {
					self::register_script($name, $props['src'], $props['deps'], $props['version']);
				}
			} else {
				self::register_script($name, $props['src'], $props['deps'], $props['version']);
			}
		}
?>
		 <script type="text/javascript">
		 	var ajax_url = "<?php echo admin_url('admin-ajax.php'); ?>";
		 	var plugins_url = "<?php echo plugins_url('datum'); ?>";
		 	var zoom 	 = "<?php echo get_option('google_zoom_map' ,''); ?>";
		 	var latitude = "<?php echo get_option('google_zoom_latitude' ,''); ?>";
		 	var longitude = "<?php echo get_option('google_zoom_longitude' ,''); ?>";
    	</script>
<?php
	}

	/**
	 * Register all DM sty;es.
	 */
	private static function register_styles()
	{
		$version = '';
		global $post;
		$register_styles = array(
			'font-awesome' => array(
				'src'     => 'https://cdnjs.cloudflare.com/ajax/libs/font-awesome/4.7.0/css/font-awesome.css',
				'deps'    => array(),
				'version' => $version,
				'has_rtl' => false,
				'pageAccess' => array(),
			),
			'slick.css'   => array(
				'src'     => self::get_asset_url('css/theme/slick.min.css'),
				'deps'    => array(),
				'version' => $version,
				'has_rtl' => false,
				'pageAccess' => array(),
			),
			'slick-theme.css'    => array(
				'src'     => self::get_asset_url('css/theme/slick-theme.min.css'),
				'deps'    => array(),
				'version' => $version,
				'has_rtl' => false,
				'pageAccess' => array(),
			),
			'kendo.default-v2.min'    => array(
				'src'     => self::get_asset_url('css/kendo.default-v2.min.css'),
				'deps'    => array(),
				'version' => $version,
				'has_rtl' => false,
				'pageAccess' => array('datum_property_listing_id', 'datum_property_closed_id'),
			),
			'lightgallery'    => array(
				'src'     => self::get_asset_url('css/theme/lightgallery.min.css'),
				'deps'    => array(),
				'version' => $version,
				'has_rtl' => false,
				'pageAccess' => array(),
			),
			'select2.min.css' => array(
				'src'     => self::get_asset_url('css/select2.min.css'),
				'deps'    => array(),
				'version' => $version,
				'has_rtl' => false,
				'pageAccess' => array(),
			),
			'cropper.css'    => array(
				'src'     => self::get_asset_url('css/cropper.min.css'),
				'deps'    => array(),
				'version' => time(), //$version,
				'has_rtl' => false,
				'pageAccess' => array(),
			),
			'style_datum'    => array(
				'src'     => self::get_asset_url('css/style.css'),
				'deps'    => array(),
				'version' => time(), //$version,
				'has_rtl' => false,
				'pageAccess' => array(),
			),
			/**
			 * Tag editor for the search text box
			 */
			'jquery-ui'    => array(
				'src'     => self::get_asset_url('css/jquery-ui.min.css'),
				'deps'    => array(),
				'version' => $version,
				'has_rtl' => false,
				'pageAccess' => array(),
			),

			'jquerysctipttop'    => array(
				'src'     => self::get_asset_url('css/jqueryscripttop.css'),
				'deps'    => array(),
				'version' => $version,
				'has_rtl' => false,
				'pageAccess' => array(),
			),
			'jquery.tagsinput-revisited'    => array(
				'src'     => self::get_asset_url('css/jquery.tagsinput-revisited.min.css'),
				'deps'    => array(),
				'version' => $version,
				'has_rtl' => false,
				'pageAccess' => array(),
			),
			'pannellum'    => array(
				'src'     => "https://cdn.jsdelivr.net/npm/pannellum@2.5.6/build/pannellum.css",
				'deps'    => array(),
				'version' => time(),
				'has_rtl' => false,
				// 'pageAccess'=> array('datum_for_lease_listing_id'),
			),

		);

		foreach ($register_styles as $name => $props) {
			if (!empty($props['pageAccess'])) {
				foreach ($props['pageAccess'] as $n => $p) {
					$id  = get_option($p);
					if ($id == $post->ID) {
						self::register_style($name, $props['src'], $props['deps'], $props['version'], 'all', $props['has_rtl']);
					}
				}
			} else {

				self::register_style($name, $props['src'], $props['deps'], $props['version'], 'all', $props['has_rtl']);
			}
		}

		$scss = new Compiler();
		$scss->setImportPaths(DM_ABSPATH . 'assets/scss/');

		$variables = self::setVariablesData(); // This should return an array of SCSS variables

		// Convert PHP values to SCSS-compatible values
		$convertedVariables = [];
		foreach ($variables as $key => $value) {
			$convertedVariables["\$$key"] = ValueConverter::fromPhp($value);
		}

		// Apply variables
		$scss->addVariables($convertedVariables);

		// Compile SCSS using compileString() instead of compile()
		$compiledCss = $scss->compileString('@import "_style.scss";')->getCss();

		// Save the compiled CSS file
		file_put_contents(DM_ABSPATH . 'css/style.css', $compiledCss . PHP_EOL);
	}


	public function prefix_add_footer_styles()
	{
		wp_enqueue_style('style_ds', plugin_dir_url('') . 'datum/css/style.css', array(), '1.0.1', 'all');
	}

	/**
	 * Register/queue frontend scripts.
	 */
	public static function load_scripts()
	{
		global $post;

		self::register_scripts();
		self::register_styles();
		// CSS Styles.

	}
	/**
	 * Register a script for use.
	 *
	 * @uses   wp_register_script()
	 * @param  string   $handle    Name of the script. Should be unique.
	 * @param  string   $path      Full URL of the script, or path of the script relative to the WordPress root directory.
	 * @param  string[] $deps      An array of registered script handles this script depends on.
	 * @param  string   $version   String specifying script version number, if it has one, which is added to the URL as a query string for cache busting purposes. If version is set to false, a version number is automatically added equal to current installed WordPress version. If set to null, no version is added.
	 * @param  boolean  $in_footer Whether to enqueue the script before </body> instead of in the <head>. Default 'false'.
	 */
	private static function register_script($handle, $path, $deps = array('jquery'), $version = DM_VERSION, $in_footer = true)
	{
		self::$scripts[] = $handle;
		wp_register_script($handle, $path, $deps, $version, $in_footer);
		wp_enqueue_script($handle);
	}
	/**
	 * Register a style for use.
	 *
	 * @uses   wp_register_style()
	 * @param  string   $handle  Name of the stylesheet. Should be unique.
	 * @param  string   $path    Full URL of the stylesheet, or path of the stylesheet relative to the WordPress root directory.
	 * @param  string[] $deps    An array of registered stylesheet handles this stylesheet depends on.
	 * @param  string   $version String specifying stylesheet version number, if it has one, which is added to the URL as a query string for cache busting purposes. If version is set to false, a version number is automatically added equal to current installed WordPress version. If set to null, no version is added.
	 * @param  string   $media   The media for which this stylesheet has been defined. Accepts media types like 'all', 'print' and 'screen', or media queries like '(orientation: portrait)' and '(max-width: 640px)'.
	 * @param  boolean  $has_rtl If has RTL version to load too.
	 */
	private static function register_style($handle, $path, $deps = array(), $version = DM_VERSION, $media = 'all', $has_rtl = false)
	{
		self::$styles[] = $handle;
		wp_register_style($handle, $path, $deps, $version, $media);
		wp_enqueue_style($handle);
	}

	/**
	 * Return asset URL.
	 *
	 * @param string $path Assets path.
	 * @return string
	 */
	private static function get_asset_url($path)
	{
		return apply_filters('datum_get_asset_url', plugins_url($path, DM_PLUGIN_FILE), $path);
	}

	public static function setVariablesData($data = [])
	{
		return
			array(
				'white'				=> '#ffffff',
				'black' 			=> '#000000',
				'font-primary-color' => '#2C2C2C',
				'font-secondary-color' => '#666666',
				'red-color' 		=> '#D22630',
				'blue-color' 		=> ' #000F9F',
				'grey-color' 		=> ' #BCBFC1',
				'linkedin-color' 	=> ' #0077B5',
				'coal-black' 		=> ' #3C3C3C',
				'light-grey-color' 	=> ' #E3E9EF',
				'light-blue-color' 	=> ' #EAF2FF',
				'dark-grey-color' 	=> ' #CCCCCC',
				'border-grey' 		=> ' #D2D2D2',
				'white-secondary' 	=> ' #F3F3F3',
				'right-body-color' 	=> '#EFF7FF',
				'box-shadow-inset' 	=> ' inset 0 0 6px rgba(0,0,0,.3)',
				'textbox-shadow' 	=> '0 0 10px rgba(0, 0, 0, 0.10)',
				'box-shadow-grey' 	=> '0px 5px 15px rgba(172, 178, 193, 1)',
				'extraBig-device' 	=> ' only screen and (min-width =>  1600px)',
				'laptop-device' 	=> 'only screen and (min-width =>  1200px) and (max-width =>  1600px)',
				'mini-laptop-device' => 'only screen and (min-width =>  1200px) and (max-width =>  1300px)',
				'desktop-device' 	=> 'only screen and (min-width =>  992px) and (max-width =>  1199px)',
				'tablet-device' 	=> 'only screen and (min-width =>  768px) and (max-width => 991px)',
				'small-mobile3' 	=> 'only screen and (min-width =>  430px) and (max-width => 575px)',
				'small-tablet' 		=> 'only screen and (max-width =>  991px)',
				'large-mobile' 		=> 'only screen and (max-width =>  767px)',
				'small-mobile2' 	=> 'only screen and (max-width =>  575px)',
				'small-mobile' 		=> 'only screen and (max-width =>  479px)',
				'xsmall-mobile' 	=> 'only screen and (max-width =>  360px)',
				'font-size0' 		=> '  0px',
				'font-size8' 		=> '  8px',
				'font-size9' 		=> '  9px',
				'font-size10' 		=> '10px',
				'font-size11' 		=> ' 11px',
				'font-size12' 		=> ' 12px',
				'font-size13'	 	=> ' 13px',
				'font-size14'		=> ' 14px',
				'font-size15' 		=> ' 15px',
				'font-size16' 		=> ' 16px',
				'font-size17' 		=> ' 17px',
				'font-size18' 		=> ' 18px',
				'font-size20' 		=> ' 20px',
				'font-size21' 		=> '21px',
				'font-size22' 		=> '22px',
				'font-size24' 		=> '24px',
				'font-size26' 		=> '26px',
				'font-size28' 		=> '28px',
				'font-size30' 		=> '30px',
				'font-size32' 		=> '32px',
				'font-size34' 		=> ' 34px',
				'font-size36' 		=> ' 36px',
				'font-size38' 		=> ' 38px',
				'font-size40' 		=> ' 40px',
				'font-size42' 		=> ' 42px',
				'font-size44' 		=> ' 44px',
				'font-size46' 		=> ' 46px',
				'font-size48' 		=> ' 48px',
				'font-size50' 		=> ' 50px',
				'font-size52' 		=> ' 52px',
				'font-size60' 		=> ' 60px',
				'font-semibold' 	=> ' 600',
				'font-regular' 		=> ' 400',
				'font-bold' 		=> ' 700',
				'font-medium' 		=> ' 500',
				'font-black' 		=> ' 900',
				'font-light' 		=> ' 300',
				'border-radius8' 	=> ' 8px',
				'border-radius6' 	=> ' 6px',
				'border-radius4' 	=> ' 4px',
				'border-radius5' 	=> ' 5px',
				'border-radius10' 	=> ' 10px',
				'border-radius0' 	=> ' 0px',
				'border-radius-round' => ' 50%',
				'dashed-border' 	=> ' dashed',
				'solid-border' 		=> ' solid',
			);
	}
}

DM_Frontend_Scripts::init();
