<?php
/**
 * datum setup
 *
 * @package datum
 * @since   3.2.0
 */

defined( 'ABSPATH' ) || exit;

/**
 * Main datum Class.
 *
 * @class datum
 */
if(!class_exists('WP_List_Table')){
   require_once( ABSPATH . 'wp-admin/includes/class-wp-list-table.php' );
}
if (!class_exists('datumPage')) {
		
	class datumPage {
		
		public function __construct() {
			$this->includes();
			$this->init_hooks();
			add_action( 'wp_head', array($this,'addHeaderHtml'), 1, 2 );
			add_action( 'wp_head', array($this,'addHeaderAgent'), 2, 2 );
			//add_filter('oembed_response_data',  array($this,'custom_oembed_title_fix'), 10, 4);
			add_filter('wpseo_opengraph_title', array($this,'custom_dynamic_og_title'),15,1);
			add_filter('wpseo_opengraph_url', array($this,'custom_yoast_og_url'),15,1);

			remove_action('wp_head', 'rest_output_link_wp_head', 10);
			remove_action('wp_head', 'wp_oembed_add_discovery_links', 10);
			add_filter('wpseo_json_ld_output', '__return_false');

		}

		public function includes() {
			foreach ( $this->pageData() as $key => $value ) {
				
				include_once DM_ABSPATH . 'includes/page/class-'.$key.'.php';
			}
		}

		public function init_hooks(){

			add_filter( 'template_include', array($this, 'include_template_function'));
		}


		public function custom_dynamic_og_title($title) {
            global $single_property, $single_insight;

            if (!empty($single_property)) {
                return getDMPropertyMetaTitle() ?: getDMPropertyName();
            } elseif (!empty($single_insight)) {
                return getDMInsightPostTitle();
            }

            return $title;
        }

        public function custom_yoast_og_url($url) {
            global $single_property, $single_insight;

            if (!empty($single_property)) {
                return getDMProperyURL();
            } elseif (!empty($single_insight)) {
                return getDMUrlSlug();
            }

            return $url;
        }

		public function custom_oembed_title_fix($data, $post, $width, $height){
			global $single_property,$post, $single_insight;
			if(isset($single_property) && !empty($single_property)){

					if(empty(getDMPropertyMetaTitle()))
					{
						$meta_title = getDMPropertyName();
					}
					else {
						$meta_title = getDMPropertyMetaTitle();
					}
				$data['title'] =$meta_title;
				return $data;
			}
			return $data;
		}

		public function addHeaderHtml(){
			global $single_property,$post, $single_insight;
			if(isset($single_property) && !empty($single_property)){

				$list = getimagesize(getDMpropertyFeaturedImageSM());
			?>
				<?php
					if(empty(getDMPropertyMetaTitle()))
					{
						$meta_title = getDMPropertyName();
					}
					else {
						$meta_title = getDMPropertyMetaTitle();
					}
			
				?>
				<title><?php echo $meta_title; ?></title>
				<meta name="description" content="<?php echo getDMPropertyMetaDescription(); ?>" />
				<meta name="robots" content="index, follow, max-snippet:-1, max-image-preview:large, max-video-preview:-1" />
				<meta property="og:locale" content="en_US" />
				<meta property="og:type" content="article" />

				<meta property="og:title" content="<?php echo $meta_title ?>" />
				<meta property="og:description" content="<?php echo getDMPropertyMetaDescription(); ?>" />
				<meta property="og:url" content="<?php echo getDMProperyURL(); ?>" />
				<meta property="og:site_name" content="<?php echo PRJECT_NAME; ?>" />
				<meta property="article:publisher" content="https://www.facebook.com/datatodeals/" />
				<meta property="article:published_time" content="2021-06-03T19:21:08+00:00" />
				<meta property="article:modified_time" content="2021-06-06T01:01:29+00:00" />
				<meta name="image" property="og:image" content="<?php echo getDMpropertyFeaturedImageSM(); ?>" />
				<meta property="og:image:width" content="<?php echo $list[0] ?>" />
				<meta property="og:image:height" content="<?php echo $list[1] ?>" />
				<meta name="twitter:card" content="summary_large_image" />
				<meta name="twitter:creator" content="@datatodeals" />
				<meta name="twitter:site" content="@datatodeals" />
				
			<?php
			} else {
				if(isset($single_insight) && !empty($single_insight)){
					if(empty(getDMInsightPostTitle()))
					{
						$meta_title = getDMInsightPostTitle();
					}
					else {
						$meta_title = getDMInsightPostTitle();
					}
					?>
					<title><?php echo $meta_title; ?></title>
					<meta name="description" content="<?php echo $single_insight->MetaDescription; ?>" />
					<meta name="robots" content="index, follow, max-snippet:-1, max-image-preview:large, max-video-preview:-1" />
					<meta property="og:url" content="<?php echo getDMUrlSlug(); ?>" />
					<meta property="og:site_name" content="<?php echo PRJECT_NAME; ?>" />
					<?php
				}else {
			        if (class_exists('WPSEO_Meta')) {
			            $seo_title = WPSEO_Meta::get_value('title', $post_id);
			            if (empty($seo_title)) {
			                $seo_title = get_the_title($post_id);
			            }
			            ?>
			           <title><?php echo $seo_title; ?>  - Colliers Western egion;</title>
			            <?php
			        }
			    }
			}
			?>
			<script type="text/javascript">
			 	var ajax_url = "<?php echo admin_url('admin-ajax.php'); ?>";
			 	var plugins_url = "<?php echo plugins_url('datum'); ?>";
			 	var zoom 	 = "<?php echo get_option('google_zoom_map' ,''); ?>";
			 	var latitude = "<?php echo get_option('google_zoom_latitude' ,''); ?>";
			 	var longitude = "<?php echo get_option('google_zoom_longitude' ,''); ?>";
	    	</script>
			<?php
		}
		

		public function addHeaderAgent(){
			global $single_property,$post;
			if($post->ID == get_option('datum_agent_id')){
				global $agentDetails;
				?>
				<title><?php echo $agentDetails->FirstName; ?> <?php echo $agentDetails->LastName; ?></title>
				
				<meta name="robots" content="index, follow, max-snippet:-1, max-image-preview:large, max-video-preview:-1" />
				<meta property="og:locale" content="en_US" />
				<meta property="og:type" content="article" />
				<meta name="description" content="<?php echo $agentDetails->FirstName; ?> <?php echo $agentDetails->LastName; ?>" />
				<?php
			}
		}


		public function include_template_function( $template_path ) {
			global $post,$wp,$property_type_filter,$siteData;
				
			global $datum_user,$site_name;
			$page_name = '';
			foreach ($this->pageData() as $key => $value) {
				$id  = get_option($value);
				
				if($id == $post->ID){
					
				
					if($value == 'datum_my_listing_page_id'){
						$page_name = $key;
						if(isset($_COOKIE['access_token']) && $_COOKIE['access_token'] != '') {
						}else{
							wp_redirect( home_url() );
						}
					}else{
						
						$page_name = $key;
					}
					 break;
				}else{
					
					$page_name = '';
				}
			}
			
			
			$data = json_decode(DM_Curl::HTTPGet('check-plugin-key'));
			//$data = DM_Curl::HTTPGet('check-plugin-key');
			if($data->status == 'success'){
				if(!get_option('ConfigurationId')){
					add_option('ConfigurationId', $data->data->ConfigurationId);
				}else{
					update_option('ConfigurationId', $data->data->ConfigurationId);
				}
				$siteData = $data->data;
				if(!empty($data->user_data)){
					$datum_user = $data->user_data;
				}else{
					unset($_COOKIE['access_token']);
					setcookie('access_token', null, -1, '/');
					//unset($_SESSION['HYBRIDAUTH::STORAGE']);
				}
				//$data = DM_Curl::HTTPPost(array('insight_id' => 30, 'is_Insightview' => 'true') , 'insight-page');
				
				
				if(isset($page_name) && $page_name != ''){

					if($page_name == 'listing' || $page_name == 'closed' || $page_name == 'for_lease'){
						add_filter( 'body_class','addListingPageClass' );
					}
					
					$instance = new $page_name();
					return $instance->output($template_path);
				}else{
					
					$args 		= get_query_var('args');
					$pagename 	= get_query_var('pagename');
					
					$ss = 'listing';
					$property_type_filter = $pagename;

					if(in_array($pagename,$this->checkpage()) && $args == 'for-sale' ){
						
						return $ss::propertyTypeOutput($template_path);
					}elseif(in_array($pagename,$this->checkpage()) && $args == 'closed' ){
						add_filter( 'body_class','addListingPageClass' );
						return $ss::propertyTypeClosedOutput($template_path);
					} elseif(in_array($pagename,$this->checkpage()) && $args == 'for-lease' ){
						add_filter( 'body_class','addListingPageClass' );
						return $ss::propertyLeaseTypeOutput($template_path);
					}elseif(in_array($pagename,$this->checkpage())){
						return $template_path = get_template_directory() . '/404.php';
					}else{

						return $template_path;
					}
				}
			}else{
				return $template_path;
			}

		}
		public function check_condition(){

		}

		public function checkpage(){
			return array(
				'office',
				'industrial',
				'retail',
				'multifamily',
				'healthcare',
				'hospitality',
				'land-development'
			);
		}

		public function pageData(){
			return array(
				'listing' 					=> 'datum_property_listing_id',
				'closed' 					=> 'datum_property_closed_id',
				'agent'        			    => 'datum_agent_id',
				'insight' 					=> 'datum_insights_page_id',
				'preview' 					=> 'datum_preview_page_id',
				'my_listing' 				=> 'datum_my_listing_page_id',
				'for_lease' 				=> 'datum_for_lease_listing_id',
				'success' 				=> 'datum_success_page_id',
				'failed' 				=> 'datum_failed_page_id'
				//'proerty_type'			=> 'datum_type_listing_page_id'
			);
		}
	}
}
return new datumPage();

function addListingPageClass($classes){
	
	$classes[] = 'listing_page_class';
    return $classes;
}